% Auto-generated chapter 8 for abudawud
% Hadiths in this chapter: 140

\hadithdefcmd{abudawud}{1416}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا عِيسَى، عَنْ زَكَرِيَّا، عَنْ أَبِي إِسْحَاقَ، عَنْ عَاصِمٍ، عَنْ عَلِيٍّ، - رضى الله عنه - قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا أَهْلَ الْقُرْآنِ أَوْتِرُوا فَإِنَّ اللَّهَ وِتْرٌ يُحِبُّ الْوِتْرَ ‏"‏ ‏.‏\hadithno{1416}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ali ibn AbuTalib: The Prophet (ﷺ) said: Allah is single (witr) and loves what is single, so observe the witr, you who follow the Qur'an}}
\hadithdefcmd{abudawud}{1417}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو حَفْصٍ الأَبَّارُ، عَنِ الأَعْمَشِ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ أَبِي عُبَيْدَةَ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَاهُ زَادَ فَقَالَ أَعْرَابِيٌّ مَا تَقُولُ فَقَالَ ‏ "‏ لَيْسَ لَكَ وَلاَ لأَصْحَابِكَ ‏"‏ ‏.‏\hadithno{1417}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{The above mentioned tradition has also been narrated by 'Abd Allah (b. Mas'ud) through a different chain of narrators to the same effect. This version adds:A bedouin said: What are you saying ? He replied: This is neither for you, nor for your companions}}
\hadithdefcmd{abudawud}{1418}{حَدَّثَنَا أَبُو الْوَلِيدِ الطَّيَالِسِيُّ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، - الْمَعْنَى - قَالاَ حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ عَبْدِ اللَّهِ بْنِ رَاشِدٍ الزَّوْفِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي مُرَّةَ الزَّوْفِيِّ، عَنْ خَارِجَةَ بْنِ حُذَافَةَ، - قَالَ أَبُو الْوَلِيدِ الْعَدَوِيُّ - قَالَ خَرَجَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ قَدْ أَمَدَّكُمْ بِصَلاَةٍ وَهِيَ خَيْرٌ لَكُمْ مِنْ حُمْرِ النَّعَمِ وَهِيَ الْوِتْرُ فَجَعَلَهَا لَكُمْ فِيمَا بَيْنَ الْعِشَاءِ إِلَى طُلُوعِ الْفَجْرِ ‏"‏ ‏.‏\hadithno{1418}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Kharijah ibn Hudhafah al-Adawi: The Messenger of Allah (ﷺ) came out to us and said: Allah the Exalted has given you an extra prayer which is better for you then the red camels (i.e. high breed camels). This is the witr which Allah has appointed for you between the night prayer and the daybreak}}
\hadithdefcmd{abudawud}{1419}{حَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا أَبُو إِسْحَاقَ الطَّالْقَانِيُّ، حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ الْعَتَكِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ الْوِتْرُ حَقٌّ فَمَنْ لَمْ يُوتِرْ فَلَيْسَ مِنَّا الْوِتْرُ حَقٌّ فَمَنْ لَمْ يُوتِرْ فَلَيْسَ مِنَّا الْوِتْرُ حَقٌّ فَمَنْ لَمْ يُوتِرْ فَلَيْسَ مِنَّا ‏"‏‏.‏\hadithno{1419}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Buraydah ibn al-Hasib: I heard the Messenger of Allah (ﷺ) say: The witr is a duty, so he who does not observe it does not belong to us; the witr is a duty, so he who does not observe it does not belong to us; the witr is a duty, so he who does not observe it does not belong to us}}
\hadithdefcmd{abudawud}{1420}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنِ ابْنِ مُحَيْرِيزٍ، أَنَّ رَجُلاً، مِنْ بَنِي كِنَانَةَ يُدْعَى الْمُخْدَجِيَّ سَمِعَ رَجُلاً، بِالشَّامِ يُدْعَى أَبَا مُحَمَّدٍ يَقُولُ إِنَّ الْوِتْرَ وَاجِبٌ ‏.‏ قَالَ الْمُخْدَجِيُّ فَرُحْتُ إِلَى عُبَادَةَ بْنِ الصَّامِتِ فَأَخْبَرْتُهُ فَقَالَ عُبَادَةُ كَذَبَ أَبُو مُحَمَّدٍ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ خَمْسُ صَلَوَاتٍ كَتَبَهُنَّ اللَّهُ عَلَى الْعِبَادِ فَمَنْ جَاءَ بِهِنَّ لَمْ يُضَيِّعْ مِنْهُنَّ شَيْئًا اسْتِخْفَافًا بِحَقِّهِنَّ كَانَ لَهُ عِنْدَ اللَّهِ عَهْدٌ أَنْ يُدْخِلَهُ الْجَنَّةَ وَمَنْ لَمْ يَأْتِ بِهِنَّ فَلَيْسَ لَهُ عِنْدَ اللَّهِ عَهْدٌ إِنْ شَاءَ عَذَّبَهُ وَإِنْ شَاءَ أَدْخَلَهُ الْجَنَّةَ ‏"‏ ‏.‏\hadithno{1420}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ubadah ibn as-Samit: Ibn Muhayriz said: A man from Banu Kinanah, named al-Makhdaji, heard a person called AbuMuhammad in Syria, saying: The witr is a duty (wajib). Al-Makhdaji said: So I went to Ubadah ibn as-Samit and informed him. Ubadah said: AbuMuhammad told a lie. I heard the Messenger of Allah (ﷺ) say: There are five prayers which Allah has prescribed on His servants. If anyone offers them, not losing any of them, and not treating them lightly, Allah guarantees that He will admit him to Paradise. If anyone does not offer them, Allah does not take any responsibility for such a person. He may either punish him or admit him to Paradise}}
\hadithdefcmd{abudawud}{1421}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَجُلاً، مِنْ أَهْلِ الْبَادِيَةِ سَأَلَ النَّبِيَّ صلى الله عليه وسلم عَنْ صَلاَةِ اللَّيْلِ فَقَالَ بِأُصْبُعَيْهِ هَكَذَا مَثْنَى مَثْنَى وَالْوِتْرُ رَكْعَةٌ مِنْ آخِرِ اللَّيْلِ ‏.‏\hadithno{1421}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (749)}\hadithtrans{Ibn 'Umar said:A man who lived in the desert asked the Messenger of Allah (ﷺ) about the prayer at night. He made a sign with his two fingers-in this way in pairs. The witr consists of one rak'ah towards the end in night}}
\hadithdefcmd{abudawud}{1422}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ الْمُبَارَكِ، حَدَّثَنِي قُرَيْشُ بْنُ حَيَّانَ الْعِجْلِيُّ، حَدَّثَنَا بَكْرُ بْنُ وَائِلٍ، عَنِ الزُّهْرِيِّ، عَنْ عَطَاءِ بْنِ يَزِيدَ اللَّيْثِيِّ، عَنْ أَبِي أَيُّوبَ الأَنْصَارِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْوِتْرُ حَقٌّ عَلَى كُلِّ مُسْلِمٍ فَمَنْ أَحَبَّ أَنْ يُوتِرَ بِخَمْسٍ فَلْيَفْعَلْ وَمَنْ أَحَبَّ أَنْ يُوتِرَ بِثَلاَثٍ فَلْيَفْعَلْ وَمَنْ أَحَبَّ أَنْ يُوتِرَ بِوَاحِدَةٍ فَلْيَفْعَلْ ‏"‏ ‏.‏\hadithno{1422}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuAyyub al-Ansari: The Prophet (ﷺ) said: The witr is a duty for every Muslim so if anyone wishes to observe it with five rak'ahs, he may do so; if anyone wishes to observe it with three, he may do so, and if anyone wishes to observe it with one, he may do so}}
\hadithdefcmd{abudawud}{1423}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو حَفْصٍ الأَبَّارُ، ح وَحَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا مُحَمَّدُ بْنُ أَنَسٍ، - وَهَذَا لَفْظُهُ - عَنِ الأَعْمَشِ، عَنْ طَلْحَةَ، وَزُبَيْدٍ، عَنْ سَعِيدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبْزَى، عَنْ أَبِيهِ، عَنْ أُبَىِّ بْنِ كَعْبٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُوتِرُ بِـ ‏\{‏ سَبِّحِ اسْمَ رَبِّكَ الأَعْلَى ‏\}‏ وَ ‏\{‏ قُلْ لِلَّذِينَ كَفَرُوا ‏\}‏ وَاللَّهُ الْوَاحِدُ الصَّمَدُ ‏.‏\hadithno{1423}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Ubayy ibn Ka'b: The Messenger of Allah (ﷺ) used to observe witr with (reciting) "Glorify the name of thy Lord, the most High" (Surah 87), "Say O disbelievers" (Surah 109), and "Say, He is Allah, the One, Allah, the eternally besought of all}}
\hadithdefcmd{abudawud}{1424}{حَدَّثَنَا أَحْمَدُ بْنُ أَبِي شُعَيْبٍ، حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، حَدَّثَنَا خُصَيْفٌ، عَنْ عَبْدِ الْعَزِيزِ بْنِ جُرَيْجٍ، قَالَ سَأَلْتُ عَائِشَةَ أُمَّ الْمُؤْمِنِينَ بِأَىِّ شَىْءٍ كَانَ يُوتِرُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَذَكَرَ مَعْنَاهُ قَالَ وَفِي الثَّالِثَةِ بِـ ‏\{‏ قُلْ هُوَ اللَّهُ أَحَدٌ ‏\}‏ وَالْمُعَوِّذَتَيْنِ ‏.‏\hadithno{1424}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: AbdulAziz ibn Jurayj said: I asked Aisha, mother of the believers: With which (surah) the Messenger of Allah (ﷺ) used to observe witr? (She reported same as in the Hadith of Ubayy ibn Ka'b, No. 1418) This version adds: In the third rak'ah he would recite: "Say, He is Allah, the One" (Surah 112), and "Say, I seek refuge in the Lord of daybreak" (Surah 113), and "Say, I seek refuge in the Lord of mankind" (Surah)}}
\hadithdefcmd{abudawud}{1425}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَأَحْمَدُ بْنُ جَوَّاسٍ الْحَنَفِيُّ، قَالاَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنْ بُرَيْدِ بْنِ أَبِي مَرْيَمَ، عَنْ أَبِي الْحَوْرَاءِ، قَالَ قَالَ الْحَسَنُ بْنُ عَلِيٍّ رضى الله عنهما عَلَّمَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم كَلِمَاتٍ أَقُولُهُنَّ فِي الْوِتْرِ قَالَ ابْنُ جَوَّاسٍ فِي قُنُوتِ الْوِتْرِ ‏ "‏ اللَّهُمَّ اهْدِنِي فِيمَنْ هَدَيْتَ وَعَافِنِي فِيمَنْ عَافَيْتَ وَتَوَلَّنِي فِيمَنْ تَوَلَّيْتَ وَبَارِكْ لِي فِيمَا أَعْطَيْتَ وَقِنِي شَرَّ مَا قَضَيْتَ إِنَّكَ تَقْضِي وَلاَ يُقْضَى عَلَيْكَ وَإِنَّهُ لاَ يَذِلُّ مَنْ وَالَيْتَ وَلاَ يَعِزُّ مَنْ عَادَيْتَ تَبَارَكْتَ رَبَّنَا وَتَعَالَيْتَ ‏"‏ ‏.‏\hadithno{1425}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Al-Hasan ibn Ali: The Messenger of Allah (ﷺ) taught me some words that I say during the witr. (The version of Ibn Jawwas has: I say them in the supplication of the witr.) They were: "O Allah, guide me among those Thou hast guided, grant me security among those Thou hast granted security, take me into Thy charge among those Thou hast taken into Thy charge, bless me in what Thou hast given, guard me from the evil of what Thou hast decreed, for Thou dost decree, and nothing is decreed for Thee. He whom Thou befriendest is not humbled. Blessed and Exalted art Thou, our Lord}}
\hadithdefcmd{abudawud}{1426}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو إِسْحَاقَ، بِإِسْنَادِهِ وَمَعْنَاهُ قَالَ فِي آخِرِهِ قَالَ هَذَا يَقُولُ فِي الْوِتْرِ فِي الْقُنُوتِ وَلَمْ يَذْكُرْ أَقُولُهُنَّ فِي الْوِتْرِ ‏.‏ قَالَ أَبُو دَاوُدَ أَبُو الْحَوْرَاءِ رَبِيعَةُ بْنُ شَيْبَانَ ‏.‏\hadithno{1426}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The aforesaid tradition has been transmitted by Abu Ishaq with the same chain and to the same effect. In the last of this tradition he said:The version has the words: "He would recite the supplication of the witr." He did not mention the words: "I say them in the witr." Abu Dawud said: The name of Abu al-Hawra' is Rabi'ah b. Shaiban}}
\hadithdefcmd{abudawud}{1427}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ هِشَامِ بْنِ عَمْرٍو الْفَزَارِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامٍ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، رضى الله عنه أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَقُولُ فِي آخِرِ وِتْرِهِ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِرِضَاكَ مِنْ سَخَطِكَ وَبِمُعَافَاتِكَ مِنْ عُقُوبَتِكَ وَأَعُوذُ بِكَ مِنْكَ لاَ أُحْصِي ثَنَاءً عَلَيْكَ أَنْتَ كَمَا أَثْنَيْتَ عَلَى نَفْسِكَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ هِشَامٌ أَقْدَمُ شَيْخٍ لِحَمَّادٍ وَبَلَغَنِي عَنْ يَحْيَى بْنِ مَعِينٍ أَنَّهُ قَالَ لَمْ يَرْوِ عَنْهُ غَيْرُ حَمَّادِ بْنِ سَلَمَةَ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَى عِيسَى بْنُ يُونُسَ عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ عَنْ قَتَادَةَ عَنْ سَعِيدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبْزَى عَنْ أَبِيهِ عَنْ أُبَىِّ بْنِ كَعْبٍ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَنَتَ - يَعْنِي فِي الْوِتْرِ - قَبْلَ الرُّكُوعِ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَى عِيسَى بْنُ يُونُسَ هَذَا الْحَدِيثَ أَيْضًا عَنْ فِطْرِ بْنِ خَلِيفَةَ عَنْ زُبَيْدٍ عَنْ سَعِيدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبْزَى عَنْ أَبِيهِ عَنْ أُبَىٍّ عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ وَرُوِيَ عَنْ حَفْصِ بْنِ غِيَاثٍ عَنْ مِسْعَرٍ عَنْ زُبَيْدٍ عَنْ سَعِيدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبْزَى عَنْ أَبِيهِ عَنْ أُبَىِّ بْنِ كَعْبٍ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَنَتَ فِي الْوِتْرِ قَبْلَ الرُّكُوعِ ‏.‏ قَالَ أَبُو دَاوُدَ حَدِيثُ سَعِيدٍ عَنْ قَتَادَةَ رَوَاهُ يَزِيدُ بْنُ زُرَيْعٍ عَنْ سَعِيدٍ عَنْ قَتَادَةَ عَنْ عَزْرَةَ عَنْ سَعِيدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبْزَى عَنْ أَبِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم لَمْ يَذْكُرِ الْقُنُوتَ وَلاَ ذَكَرَ أُبَيًّا وَكَذَلِكَ رَوَاهُ عَبْدُ الأَعْلَى وَمُحَمَّدُ بْنُ بِشْرٍ الْعَبْدِيُّ وَسَمَاعُهُ بِالْكُوفَةِ مَعَ عِيسَى بْنِ يُونُسَ وَلَمْ يَذْكُرُوا الْقُنُوتَ وَقَدْ رَوَاهُ أَيْضًا هِشَامٌ الدَّسْتَوَائِيُّ وَشُعْبَةُ عَنْ قَتَادَةَ وَلَمْ يَذْكُرَا الْقُنُوتَ وَحَدِيثُ زُبَيْدٍ رَوَاهُ سُلَيْمَانُ الأَعْمَشُ وَشُعْبَةُ وَعَبْدُ الْمَلِكِ بْنُ أَبِي سُلَيْمَانَ وَجَرِيرُ بْنُ حَازِمٍ كُلُّهُمْ عَنْ زُبَيْدٍ لَمْ يَذْكُرْ أَحَدٌ مِنْهُمُ الْقُنُوتَ إِلاَّ مَا رُوِيَ عَنْ حَفْصِ بْنِ غِيَاثٍ عَنْ مِسْعَرٍ عَنْ زُبَيْدٍ فَإِنَّهُ قَالَ فِي حَدِيثِهِ إِنَّهُ قَنَتَ قَبْلَ الرُّكُوعِ ‏.‏ قَالَ أَبُو دَاوُدَ وَلَيْسَ هُوَ بِالْمَشْهُورِ مِنْ حَدِيثِ حَفْصٍ نَخَافُ أَنْ يَكُونَ عَنْ حَفْصٍ عَنْ غَيْرِ مِسْعَرٍ ‏.‏ قَالَ أَبُو دَاوُدَ وَيُرْوَى أَنَّ أُبَيًّا كَانَ يَقْنُتُ فِي النِّصْفِ مِنْ شَهْرِ رَمَضَانَ ‏.‏\hadithno{1427}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Ali ibn AbuTalib: The Messenger of Allah (ﷺ) used to say at the end of his witr: "O Allah, I seek refuge in Thy good pleasure from Thy anger, and in Thy forgiveness from Thy punishment, and I seek refuge in Thy mercy from Thy wrath. I cannot reckon the praise due to Thee. Thou art as Thou hast praised Thyself." Abu Dawud said: Hisham is the earliest teacher of Hammad. Yahya b. Ma'in said: No one is reported to have narrated traditions form him except Hammad b. Salamah. Abu Dawud said: Ubayy b. Ka'b said: The Messenger of Allah (ﷺ) recited supplication in the witr before bowing. Abu Dawud said: This tradition has also been narrated by 'Isa b. Yunus through a different chain of narrators from Ubayy b. Ka'b. He also narrated it through a different chain of narrators on the authority of Ubayy b. Ka'b that the Messenger of Allah (ﷺ) recited the supplication in the witr before bowing. Abu Dawud said: The chain of narrators of the tradition of Sa'id from Qatadah goes: Yazid b. Zurai' narrated from Sa'id, from Qatadah, from 'Azrah, from Sa'id b. 'Abd al-Rahman b. Abza, on the authority of his father, from the Prophet (ﷺ). This version does not mention the supplication and the name of Ubayy. This tradition has also been narrated by 'Abd al-A'la and Muhammad b. Bishr al-'Abdi. He heard the traditions from 'Isa b. Yunus at Kufah. They did not mention the supplication in their version. This tradition has also been narrated by Hisham al-Dastuwa'i and Shu'bah from Qatadah. They did not mention the supplication in their version. The tradition of Zubaid has been narrated by Sulaiman al-A'mash, Shu'bah, 'Abd al-Malik b. Abi Sulaiman, and Jarir b. Hazim; all of them narrated on the authority of Zubaid. None of them mention the supplication in his version, except in the tradition transmitted by Hafs b. Ghiyath from Mis'ar from Zubaid; he narrated in his version that he (the Prophet) recited supplication before bowing. Abu Dawud said: This version of tradition is not well know. There is doubt that Hafs might have narrated this tradition from some other narrator than Mis'ar. Abu Dawud said: It is reported that Ubayy (b. Ka'b) used to recited the supplication )in the witr) in the second half of Ramadan}}
\hadithdefcmd{abudawud}{1428}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ حَنْبَلٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ، أَخْبَرَنَا هِشَامٌ، عَنْ مُحَمَّدٍ، عَنْ بَعْضِ، أَصْحَابِهِ أَنَّ أُبَىَّ بْنَ كَعْبٍ، أَمَّهُمْ - يَعْنِي فِي رَمَضَانَ - وَكَانَ يَقْنُتُ فِي النِّصْفِ الآخِرِ مِنْ رَمَضَانَ ‏.‏\hadithno{1428}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Muhammad reported on the authority of some of his teachers that Ubayy b. Ka'b led them in prayer during Ramadan. He used to recite the supplication (in the witr) during the second half of Ramadan}}
\hadithdefcmd{abudawud}{1429}{حَدَّثَنَا شُجَاعُ بْنُ مَخْلَدٍ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا يُونُسُ بْنُ عُبَيْدٍ، عَنِ الْحَسَنِ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، جَمَعَ النَّاسَ عَلَى أُبَىِّ بْنِ كَعْبٍ فَكَانَ يُصَلِّي لَهُمْ عِشْرِينَ لَيْلَةً وَلاَ يَقْنُتُ بِهِمْ إِلاَّ فِي النِّصْفِ الْبَاقِي فَإِذَا كَانَتِ الْعَشْرُ الأَوَاخِرُ تَخَلَّفَ فَصَلَّى فِي بَيْتِهِ فَكَانُوا يَقُولُونَ أَبَقَ أُبَىٌّ ‏.‏ قَالَ أَبُو دَاوُدَ وَهَذَا يَدُلُّ عَلَى أَنَّ الَّذِي ذُكِرَ فِي الْقُنُوتِ لَيْسَ بِشَىْءٍ وَهَذَانِ الْحَدِيثَانِ يَدُلاَّنِ عَلَى ضَعْفِ حَدِيثِ أُبَىٍّ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَنَتَ فِي الْوِتْرِ ‏.‏\hadithno{1429}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ubayy ibn Ka'b: Al-Hasan reported: Umar ibn al-Khattab gathered the people (in tarawih prayer) behind Ubayy ibn Ka'b (who led them). He used to lead them for twenty days (during Ramadan, and would not recite the supplication except in the second half of it (i.e. Ramadan). When the last ten days remained, he kept away from them, and prayed in his house. They used to say: Ubayy ran away. Abu Dawud said: This tradition shows that whatever has been reported about the recitation of the supplication is not tenable. Moreover, these two traditions from Ubayy b. Ka'b indicate that another tradition which tells that the Prophet (ﷺ) recited the supplication in the witr is weak}}
\hadithdefcmd{abudawud}{1430}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي عُبَيْدَةَ، حَدَّثَنَا أَبِي، عَنِ الأَعْمَشِ، عَنْ طَلْحَةَ الأَيَامِيِّ، عَنْ ذَرٍّ، عَنْ سَعِيدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبْزَى، عَنْ أَبِيهِ، عَنْ أُبَىِّ بْنِ كَعْبٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا سَلَّمَ فِي الْوِتْرِ قَالَ ‏ "‏ سُبْحَانَ الْمَلِكِ الْقُدُّوسِ ‏"‏ ‏.‏\hadithno{1430}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Ubayy ibn Ka'b: When the Messenger of Allah (ﷺ) offered salutation in the witr prayer, he said: Glorify be to the king most holy}}
\hadithdefcmd{abudawud}{1431}{حَدَّثَنَا مُحَمَّدُ بْنُ عَوْفٍ، حَدَّثَنَا عُثْمَانُ بْنُ سَعِيدٍ، عَنْ أَبِي غَسَّانَ، مُحَمَّدِ بْنِ مُطَرِّفٍ الْمَدَنِيِّ عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ نَامَ عَنْ وِتْرِهِ أَوْ نَسِيَهُ فَلْيُصَلِّهِ إِذَا ذَكَرَهُ ‏"‏ ‏.‏\hadithno{1431}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuSa'id al-Khudri: The Prophet (ﷺ) said: If anyone oversleeps and misses the witr, or forgets it, he should pray when he remembers}}
\hadithdefcmd{abudawud}{1432}{حَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا أَبَانُ بْنُ يَزِيدَ، عَنْ قَتَادَةَ، عَنْ أَبِي سَعِيدٍ، - مِنْ أَزْدِ شَنُوءَةَ - عَنْ أَبِي هُرَيْرَةَ، قَالَ أَوْصَانِي خَلِيلِي صلى الله عليه وسلم بِثَلاَثٍ لاَ أَدَعُهُنَّ فِي سَفَرٍ وَلاَ حَضَرٍ رَكْعَتَىِ الضُّحَى وَصَوْمِ ثَلاَثَةِ أَيَّامٍ مِنَ الشَّهْرِ وَأَنْ لاَ أَنَامَ إِلاَّ عَلَى وِتْرٍ ‏.‏\hadithno{1432}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah said:My friend (i.e. the Prophet) instructed me to observe three practices that I do not leave while traveling nor while resident, to pray two rak`ahs in the forenoon, to fast three days every month and not to sleep but after observing the witr}}
\hadithdefcmd{abudawud}{1433}{حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ نَجْدَةَ، حَدَّثَنَا أَبُو الْيَمَانِ، عَنْ صَفْوَانَ بْنِ عَمْرٍو، عَنْ أَبِي إِدْرِيسَ السَّكُونِيِّ، عَنْ جُبَيْرِ بْنِ نُفَيْرٍ، عَنْ أَبِي الدَّرْدَاءِ، قَالَ ‏"‏ أَوْصَانِي خَلِيلِي صلى الله عليه وسلم بِثَلاَثٍ لاَ أَدَعُهُنَّ لِشَىْءٍ أَوْصَانِي بِصِيَامِ ثَلاَثَةِ أَيَّامٍ مِنْ كُلِّ شَهْرٍ وَلاَ أَنَامُ إِلاَّ عَلَى وِتْرٍ وَبِسُبْحَةِ الضُّحَى فِي الْحَضَرِ وَالسَّفَرِ ‏.‏\hadithno{1433}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Abu Al-Darda' said:My friend (i.e. the Prophet) instructed me to observe three practices which I never leave: he instructed me to fast three days every month, and not to sleep but after observing the witr, and to observe supererogatory prayer in the forenoon while traveling and while resident}}
\hadithdefcmd{abudawud}{1434}{حَدَّثَنَا مُحَمَّدُ بْنُ أَحْمَدَ بْنِ أَبِي خَلَفٍ، حَدَّثَنَا أَبُو زَكَرِيَّا، يَحْيَى بْنُ إِسْحَاقَ السَّيْلَحِينِيُّ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ عَبْدِ اللَّهِ بْنِ رَبَاحٍ، عَنْ أَبِي قَتَادَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لأَبِي بَكْرٍ ‏"‏ مَتَى تُوتِرُ ‏"‏ قَالَ أُوتِرُ مِنْ أَوَّلِ اللَّيْلِ ‏.‏ وَقَالَ لِعُمَرَ ‏"‏ مَتَى تُوتِرُ ‏"‏ ‏.‏ قَالَ آخِرَ اللَّيْلِ ‏.‏ فَقَالَ لأَبِي بَكْرٍ ‏"‏ أَخَذَ هَذَا بِالْحَزْمِ ‏"‏ ‏.‏ وَقَالَ لِعُمَرَ ‏"‏ أَخَذَ هَذَا بِالْقُوَّةِ ‏"‏ ‏.‏\hadithno{1434}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated AbuQatadah: The Prophet (ﷺ) asked AbuBakr: When do you observe the witr? He replied: I observe the witr prayer in the early hours of the night. The Prophet (ﷺ) asked Umar: When do you observe the witr? He replied: At the end of the night. He then said to AbuBakr: This has followed it with care; and he said to Umar: He has followed it with strength}}
\hadithdefcmd{abudawud}{1435}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنِ الأَعْمَشِ، عَنْ مُسْلِمٍ، عَنْ مَسْرُوقٍ، قَالَ قُلْتُ لِعَائِشَةَ مَتَى كَانَ يُوتِرُ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَتْ كُلَّ ذَلِكَ قَدْ فَعَلَ أَوْتَرَ أَوَّلَ اللَّيْلِ وَوَسَطَهُ وَآخِرَهُ وَلَكِنِ انْتَهَى وِتْرُهُ حِينَ مَاتَ إِلَى السَّحَرِ ‏.‏\hadithno{1435}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (745)}\hadithtrans{Masruq said:I asked 'Aishah: When would the Messenger of Allah (ﷺ) observe the witr prayer ? She replied: Any time he observed the witr, sometimes in the early hours of the night, sometimes at midnight and sometimes towards the end of it. But he used to observe the witr just before the dawn when he died}}
\hadithdefcmd{abudawud}{1436}{حَدَّثَنَا هَارُونُ بْنُ مَعْرُوفٍ، حَدَّثَنَا ابْنُ أَبِي زَائِدَةَ، قَالَ حَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ بَادِرُوا الصُّبْحَ بِالْوِتْرِ ‏"‏ ‏.‏\hadithno{1436}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn 'Umar reported the Prophet (ﷺ) as saying:Make haste to observe the witr prayer before morning}}
\hadithdefcmd{abudawud}{1437}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَيْسٍ، قَالَ سَأَلْتُ عَائِشَةَ عَنْ وِتْرِ، رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَتْ رُبَّمَا أَوْتَرَ أَوَّلَ اللَّيْلِ وَرُبَّمَا أَوْتَرَ مِنْ آخِرِهِ ‏.‏ قُلْتُ كَيْفَ كَانَتْ قِرَاءَتُهُ أَكَانَ يُسِرُّ بِالْقِرَاءَةِ أَمْ يَجْهَرُ قَالَتْ كُلَّ ذَلِكَ كَانَ يَفْعَلُ رُبَّمَا أَسَرَّ وَرُبَّمَا جَهَرَ وَرُبَّمَا اغْتَسَلَ فَنَامَ وَرُبَّمَا تَوَضَّأَ فَنَامَ ‏.‏ قَالَ أَبُو دَاوُدَ وَقَالَ غَيْرُ قُتَيْبَةَ تَعْنِي فِي الْجَنَابَةِ ‏.‏\hadithno{1437}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abd Allah b. Abu Qais said:I asked 'Aishah about the witr observes by the Messenger of Allah (ﷺ). She replied: Sometime he observed the witr prayer in the early hours of the night, sometimes he observed it at the end of it. I asked: How did he recite the Qur'an ? Did he recite the Qur'an quietly or loudly ? She replied: He did it in any way. Sometimes he recited quietly and sometimes loudly, sometimes he took bath and then slept and sometimes he performed ablution and then slept. Abu Dawud said: The narrators other than Qutaibah said: This refer to his bath due to sexual defilement}}
\hadithdefcmd{abudawud}{1438}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، حَدَّثَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ اجْعَلُوا آخِرَ صَلاَتِكُمْ بِاللَّيْلِ وِتْرًا ‏"‏ ‏.‏\hadithno{1438}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (998) Sahih Muslim (751)}\hadithtrans{Ibn 'Umar reported the Prophet (ﷺ) as suing:Make the last of your prayer at night a witr}}
\hadithdefcmd{abudawud}{1439}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا مُلاَزِمُ بْنُ عَمْرٍو، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بَدْرٍ، عَنْ قَيْسِ بْنِ طَلْقٍ، قَالَ زَارَنَا طَلْقُ بْنُ عَلِيٍّ فِي يَوْمٍ مِنْ رَمَضَانَ وَأَمْسَى عِنْدَنَا وَأَفْطَرَ ثُمَّ قَامَ بِنَا تِلْكَ اللَّيْلَةَ وَأَوْتَرَ بِنَا ثُمَّ انْحَدَرَ إِلَى مَسْجِدِهِ فَصَلَّى بِأَصْحَابِهِ حَتَّى إِذَا بَقِيَ الْوِتْرُ قَدَّمَ رَجُلاً فَقَالَ أَوْتِرْ بِأَصْحَابِكَ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ وِتْرَانِ فِي لَيْلَةٍ ‏"‏ ‏.‏\hadithno{1439}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Talq ibn Ali: Qays ibn Talq said: Talq ibn Ali visited us on a certain day during Ramadan. He remained with us till evening and broke fast with us. He then stood up and led us in the witr prayer. He then went to his mosque and led them in prayer. When the witr remained, he put forward another man and said: Lead your companions in the witr prayer, for I heard the Messenger of Allah (ﷺ) as saying: There are no two witrs during one night}}
\hadithdefcmd{abudawud}{1440}{حَدَّثَنَا دَاوُدُ بْنُ أُمَيَّةَ، حَدَّثَنَا مُعَاذٌ، - يَعْنِي ابْنَ هِشَامٍ - حَدَّثَنِي أَبِي، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، قَالَ حَدَّثَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، حَدَّثَنَا أَبُو هُرَيْرَةَ، قَالَ وَاللَّهِ لأُقَرِّبَنَّ بِكُمْ صَلاَةَ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ فَكَانَ أَبُو هُرَيْرَةَ يَقْنُتُ فِي الرَّكْعَةِ الآخِرَةِ مِنْ صَلاَةِ الظُّهْرِ وَصَلاَةِ الْعِشَاءِ الآخِرَةِ وَصَلاَةِ الصُّبْحِ فَيَدْعُو لِلْمُؤْمِنِينَ وَيَلْعَنُ الْكَافِرِينَ ‏.‏\hadithno{1440}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (797) Sahih Muslim (676)}\hadithtrans{Abu Hurairah said:By Allah, I shall offer prayer like that of the Messenger of Allah (ﷺ). The narrator said: Abu Hurairah used to recite the supplication in the last rak'ah of the noon, night and dawn prayers. He would supplicate for the believers and curse the disbelievers}}
\hadithdefcmd{abudawud}{1441}{حَدَّثَنَا أَبُو الْوَلِيدِ، وَمُسْلِمُ بْنُ إِبْرَاهِيمَ، وَحَفْصُ بْنُ عُمَرَ، ح وَحَدَّثَنَا ابْنُ مُعَاذٍ، حَدَّثَنِي أَبِي قَالُوا، كُلُّهُمْ حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنِ ابْنِ أَبِي لَيْلَى، عَنِ الْبَرَاءِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقْنُتُ فِي صَلاَةِ الصُّبْحِ زَادَ ابْنُ مُعَاذٍ وَصَلاَةِ الْمَغْرِبِ ‏.‏\hadithno{1441}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (678)}\hadithtrans{Al-Bara' said:The Prophet (ﷺ) used to recite the supplication in the dawn prayer. The version of Ibn Mu'adh has the words: "sunset prayer}}
\hadithdefcmd{abudawud}{1442}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا الْوَلِيدُ، حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنِي يَحْيَى بْنُ أَبِي كَثِيرٍ، حَدَّثَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَنَتَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي صَلاَةِ الْعَتَمَةِ شَهْرًا يَقُولُ فِي قُنُوتِهِ ‏"‏ اللَّهُمَّ نَجِّ الْوَلِيدَ بْنَ الْوَلِيدِ اللَّهُمَّ نَجِّ سَلَمَةَ بْنَ هِشَامٍ اللَّهُمَّ نَجِّ الْمُسْتَضْعَفِينَ مِنَ الْمُؤْمِنِينَ اللَّهُمَّ اشْدُدْ وَطْأَتَكَ عَلَى مُضَرَ اللَّهُمَّ اجْعَلْهَا عَلَيْهِمْ سِنِينَ كَسِنِي يُوسُفَ ‏"‏ ‏.‏ قَالَ أَبُو هُرَيْرَةَ وَأَصْبَحَ رَسُولُ اللَّهِ صلى الله عليه وسلم ذَاتَ يَوْمٍ فَلَمْ يَدْعُ لَهُمْ فَذَكَرْتُ ذَلِكَ لَهُ فَقَالَ ‏"‏ وَمَا تَرَاهُمْ قَدْ قَدِمُوا ‏"‏ ‏.‏\hadithno{1442}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (675)}\hadithtrans{Abu Hurairah said:The Messenger of Allah (ﷺ) recited the supplication in the night prayer for a month. He said (in his supplication): O Allah, rescue al-Walid b. al-Walid, rescue Salamah b. Hisham, rescue the weak believers; O Allah, trample severely on Mudar; O Allah, cause them a famine like that of Joseph. Abu Hurairah said: One morning the Messenger of Allah (ﷺ) id not make supplication for them. So I told him about it. He said: You dod not see that they have come (back)}}
\hadithdefcmd{abudawud}{1443}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُعَاوِيَةَ الْجُمَحِيُّ، حَدَّثَنَا ثَابِتُ بْنُ يَزِيدَ، عَنْ هِلاَلِ بْنِ خَبَّابٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَنَتَ رَسُولُ اللَّهِ صلى الله عليه وسلم شَهْرًا مُتَتَابِعًا فِي الظُّهْرِ وَالْعَصْرِ وَالْمَغْرِبِ وَالْعِشَاءِ وَصَلاَةِ الصُّبْحِ فِي دُبُرِ كُلِّ صَلاَةٍ إِذَا قَالَ ‏ "‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏"‏ ‏.‏ مِنَ الرَّكْعَةِ الآخِرَةِ يَدْعُو عَلَى أَحْيَاءٍ مِنْ بَنِي سُلَيْمٍ عَلَى رِعْلٍ وَذَكْوَانَ وَعُصَيَّةَ وَيُؤَمِّنُ مَنْ خَلْفَهُ ‏.‏\hadithno{1443}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: The Messenger of Allah (ﷺ) recited the supplication (Qunut) daily for a month at the noon, afternoon, sunset, night and morning prayers. When he said: "Allah listens to him who praises Him" in the last rak'ah, invoking a curse on some clans of Banu Sulaym, Ri'l, Dhakwan and Usayyah, and those who were standing behind him said: Amen}}
\hadithdefcmd{abudawud}{1444}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، وَمُسَدَّدٌ، قَالاَ حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّهُ سُئِلَ هَلْ قَنَتَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي صَلاَةِ الصُّبْحِ فَقَالَ نَعَمْ ‏.‏ فَقِيلَ لَهُ قَبْلَ الرُّكُوعِ أَوْ بَعْدَ الرُّكُوعِ قَالَ بَعْدَ الرُّكُوعِ ‏.‏ قَالَ مُسَدَّدٌ بِيَسِيرٍ ‏.‏\hadithno{1444}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1001) Sahih Muslim (677)}\hadithtrans{Muhammad reported:Anas b. Malik was asked whether the Messenger of Allah (ﷺ) had recited supplication in the dawn prayer. He replied: Yes. He was again asked whether before bowing or after bowing. He said after bowing. This version of Musaddad adds the words: "For a short period}}
\hadithdefcmd{abudawud}{1445}{حَدَّثَنَا أَبُو الْوَلِيدِ الطَّيَالِسِيُّ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ أَنَسِ بْنِ سِيرِينَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَنَتَ شَهْرًا ثُمَّ تَرَكَهُ ‏.‏\hadithno{1445}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (677)}\hadithtrans{Anas b. Malik said:The Prophet (ﷺ) recited the supplication for a month (in prayer) and then gave it up}}
\hadithdefcmd{abudawud}{1446}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا بِشْرُ بْنُ مُفَضَّلٍ، حَدَّثَنَا يُونُسُ بْنُ عُبَيْدٍ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، قَالَ حَدَّثَنِي مَنْ، صَلَّى مَعَ النَّبِيِّ صلى الله عليه وسلم صَلاَةَ الْغَدَاةِ فَلَمَّا رَفَعَ رَأْسَهُ مِنَ الرَّكْعَةِ الثَّانِيَةِ قَامَ هُنَيَّةً ‏.‏\hadithno{1446}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Someone who prayed with the Prophet: Muhammad ibn Sirin said: Someone who prayed the morning prayer along with the Prophet (ﷺ) narrated to me: When he raised his head after the second rak'ah, he remained standing for a short while}}
\hadithdefcmd{abudawud}{1447}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ الْبَزَّازُ، حَدَّثَنَا مَكِّيُّ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا عَبْدُ اللَّهِ، - يَعْنِي ابْنَ سَعِيدِ بْنِ أَبِي هِنْدٍ - عَنْ أَبِي النَّضْرِ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ زَيْدِ بْنِ ثَابِتٍ، أَنَّهُ قَالَ احْتَجَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الْمَسْجِدِ حُجْرَةً فَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَخْرُجُ مِنَ اللَّيْلِ فَيُصَلِّي فِيهَا قَالَ فَصَلَّوْا مَعَهُ بِصَلاَتِهِ - يَعْنِي رِجَالاً - وَكَانُوا يَأْتُونَهُ كُلَّ لَيْلَةٍ حَتَّى إِذَا كَانَ لَيْلَةً مِنَ اللَّيَالِي لَمْ يَخْرُجْ إِلَيْهِمْ رَسُولُ اللَّهِ صلى الله عليه وسلم فَتَنَحْنَحُوا وَرَفَعُوا أَصْوَاتَهُمْ وَحَصَبُوا بَابَهُ - قَالَ - فَخَرَجَ إِلَيْهِمْ رَسُولُ اللَّهِ صلى الله عليه وسلم مُغْضَبًا فَقَالَ ‏ "‏ يَا أَيُّهَا النَّاسُ مَا زَالَ بِكُمْ صَنِيعُكُمْ حَتَّى ظَنَنْتُ أَنْ سَتُكْتَبَ عَلَيْكُمْ فَعَلَيْكُمْ بِالصَّلاَةِ فِي بُيُوتِكُمْ فَإِنَّ خَيْرَ صَلاَةِ الْمَرْءِ فِي بَيْتِهِ إِلاَّ الصَّلاَةَ الْمَكْتُوبَةَ ‏"‏ ‏.‏\hadithno{1447}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6113) Sahih Muslim (781)}\hadithtrans{Zaid b. Thabit said:The Messenger of Allah (ﷺ) built a chamber in the mosque. He used to come out at night and pray there. They (the people) also prayed along with him. They would come (to prayer) every night. If on any night the Messenger of Allah (ﷺ) did not come out, they would cough, raise their voices and throw pebbles and sand on his door. The Messenger of Allah (ﷺ) came out to time in anger and said: O People, you kept on doing this till I thought that it will be prescribed for you. Offer your prayers in your houses, for a man's prayer is better in his house except obligatory prayer}}
\hadithdefcmd{abudawud}{1448}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، أَخْبَرَنَا نَافِعٌ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اجْعَلُوا فِي بُيُوتِكُمْ مِنْ صَلاَتِكُمْ وَلاَ تَتَّخِذُوهَا قُبُورًا ‏"‏ ‏.‏\hadithno{1448}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (432) Sahih Muslim (77)}\hadithtrans{Ibn 'Umar reported the Messenger of Allah (ﷺ) as saying:Some offer prayer in your houses; do not make them graves}}
\hadithdefcmd{abudawud}{1449}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا حَجَّاجٌ، قَالَ قَالَ ابْنُ جُرَيْجٍ حَدَّثَنِي عُثْمَانُ بْنُ أَبِي سُلَيْمَانَ، عَنْ عَلِيٍّ الأَزْدِيِّ، عَنْ عُبَيْدِ بْنِ عُمَيْرٍ، عَنْ عَبْدِ اللَّهِ بْنِ حُبْشِيٍّ الْخَثْعَمِيِّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم سُئِلَ أَىُّ الأَعْمَالِ أَفْضَلُ قَالَ ‏"‏ طُولُ الْقِيَامِ ‏"‏ ‏.‏ قِيلَ فَأَىُّ الصَّدَقَةِ أَفْضَلُ قَالَ ‏"‏ جُهْدُ الْمُقِلِّ ‏"‏ ‏.‏ قِيلَ فَأَىُّ الْهِجْرَةِ أَفْضَلُ قَالَ ‏"‏ مَنْ هَجَرَ مَا حَرَّمَ اللَّهُ عَلَيْهِ ‏"‏ ‏.‏ قِيلَ فَأَىُّ الْجِهَادِ أَفْضَلُ قَالَ ‏"‏ مَنْ جَاهَدَ الْمُشْرِكِينَ بِمَالِهِ وَنَفْسِهِ ‏"‏ ‏.‏ قِيلَ فَأَىُّ الْقَتْلِ أَشْرَفُ قَالَ ‏"‏ مَنْ أُهْرِيقَ دَمُهُ وَعُقِرَ جَوَادُهُ ‏"‏ ‏.‏\hadithno{1449}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abd Allah b. Habshi al-Khath'ami said:The Prophet (ﷺ) was asked: Which of the actions is better ? He replied: Standing for long time (in prayer). He was again asked: Which alms is better ? He replied: The alms given by a man possessing small property acquired by his labour}}
\hadithdefcmd{abudawud}{1450}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى، عَنِ ابْنِ عَجْلاَنَ، حَدَّثَنَا الْقَعْقَاعُ بْنُ حَكِيمٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ‏ "‏ رَحِمَ اللَّهُ رَجُلاً قَامَ مِنَ اللَّيْلِ فَصَلَّى وَأَيْقَظَ امْرَأَتَهُ فَصَلَّتْ فَإِنْ أَبَتْ نَضَحَ فِي وَجْهِهَا الْمَاءَ رَحِمَ اللَّهُ امْرَأَةً قَامَتْ مِنَ اللَّيْلِ فَصَلَّتْ وَأَيْقَظَتْ زَوْجَهَا فَإِنْ أَبَى نَضَحَتْ فِي وَجْهِهِ الْمَاءَ ‏"‏ ‏.‏\hadithno{1450}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: May Allah show mercy to a man who gets up during the night and prays, who wakens his wife and she prays; if she refuses, he sprinkles water on her face. May Allah show mercy to a woman who gets up during the night and prays, who wakens her husband and he prays; if he refuses she sprinkles water on his face}}
\hadithdefcmd{abudawud}{1451}{حَدَّثَنَا مُحَمَّدُ بْنُ حَاتِمِ بْنِ بَزِيعٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ شَيْبَانَ، عَنِ الأَعْمَشِ، عَنْ عَلِيِّ بْنِ الأَقْمَرِ، عَنِ الأَغَرِّ أَبِي مُسْلِمٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، وَأَبِي، هُرَيْرَةَ قَالاَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنِ اسْتَيْقَظَ مِنَ اللَّيْلِ وَأَيْقَظَ امْرَأَتَهُ فَصَلَّيَا رَكْعَتَيْنِ جَمِيعًا كُتِبَا مِنَ الذَّاكِرِينَ اللَّهَ كَثِيرًا وَالذَّاكِرَاتِ ‏"‏ ‏.‏\hadithno{1451}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuSa'id ; AbuHurayrah: The Prophet (ﷺ) said: When a man himself wakes at night and wakens his wife and they pray two rak'ahs together, they are recorded among the men and women who make much mention of Allah}}
\hadithdefcmd{abudawud}{1452}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ عُثْمَانَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ خَيْرُكُمْ مَنْ تَعَلَّمَ الْقُرْآنَ وَعَلَّمَهُ ‏"‏ ‏.‏\hadithno{1452}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5027)}\hadithtrans{Uthman reported the Prophet (ﷺ) as saying:The best among you is he who learns and teaches the Qur'an}}
\hadithdefcmd{abudawud}{1453}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يَحْيَى بْنُ أَيُّوبَ، عَنْ زَبَّانَ بْنِ فَائِدٍ، عَنْ سَهْلِ بْنِ مُعَاذٍ الْجُهَنِيِّ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَرَأَ الْقُرْآنَ وَعَمِلَ بِمَا فِيهِ أُلْبِسَ وَالِدَاهُ تَاجًا يَوْمَ الْقِيَامَةِ ضَوْؤُهُ أَحْسَنُ مِنْ ضَوْءِ الشَّمْسِ فِي بُيُوتِ الدُّنْيَا لَوْ كَانَتْ فِيكُمْ فَمَا ظَنُّكُمْ بِالَّذِي عَمِلَ بِهَذَا ‏"‏ ‏.‏\hadithno{1453}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Mu'adh al-Juhani reported the Messenger of Allah (ﷺ) as saying:If anyone recites the Qur'an and acts according to its content, on the Day of Judgement his parents will be given to wear a crown whose light is better than the light of the sun in the dwellings of this world if it were among you. So what do you think of him who acts according to this ?}}
\hadithdefcmd{abudawud}{1454}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هِشَامٌ، وَهَمَّامٌ، عَنْ قَتَادَةَ، عَنْ زُرَارَةَ بْنِ أَوْفَى، عَنْ سَعْدِ بْنِ هِشَامٍ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الَّذِي يَقْرَأُ الْقُرْآنَ وَهُوَ مَاهِرٌ بِهِ مَعَ السَّفَرَةِ الْكِرَامِ الْبَرَرَةِ وَالَّذِي يَقْرَؤُهُ وَهُوَ يَشْتَدُّ عَلَيْهِ فَلَهُ أَجْرَانِ ‏"‏ ‏.‏\hadithno{1454}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (4937) Sahih Muslim (897)}\hadithtrans{Aishah reported the Prophet (ﷺ) as saying:One who is skilled in the Qur'an is associated with the noble, upright recording angels, and he who falters when he recites the Qur'an and finds it difficult for him will have a double reward}}
\hadithdefcmd{abudawud}{1455}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا اجْتَمَعَ قَوْمٌ فِي بَيْتٍ مِنْ بُيُوتِ اللَّهِ تَعَالَى يَتْلُونَ كِتَابَ اللَّهِ وَيَتَدَارَسُونَهُ بَيْنَهُمْ إِلاَّ نَزَلَتْ عَلَيْهِمُ السَّكِينَةُ وَغَشِيَتْهُمُ الرَّحْمَةُ وَحَفَّتْهُمُ الْمَلاَئِكَةُ وَذَكَرَهُمُ اللَّهُ فِيمَنْ عِنْدَهُ ‏"‏ ‏.‏\hadithno{1455}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2699)}\hadithtrans{Abu Hurairah reported the Prophet (ﷺ) as saying:No people get together in a house of the houses of Allah (i.e. a mosque), reciting the Book of Allah, and learning it together among themselves, but calmness (sakinah) comes down to them, (Divine) mercy covers them (from above), and the angels surround them, and Allah makes a mention of them among those who are with Him}}
\hadithdefcmd{abudawud}{1456}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْمَهْرِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، حَدَّثَنَا مُوسَى بْنُ عُلَىِّ بْنِ رَبَاحٍ، عَنْ أَبِيهِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ الْجُهَنِيِّ، قَالَ خَرَجَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَنَحْنُ فِي الصُّفَّةِ فَقَالَ ‏"‏ أَيُّكُمْ يُحِبُّ أَنْ يَغْدُوَ إِلَى بُطْحَانَ أَوِ الْعَقِيقِ فَيَأْخُذَ نَاقَتَيْنِ كَوْمَاوَيْنِ زَهْرَاوَيْنِ بِغَيْرِ إِثْمٍ بِاللَّهِ عَزَّ وَجَلَّ وَلاَ قَطْعِ رَحِمٍ ‏"‏ ‏.‏ قَالُوا كُلُّنَا يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ فَلأَنْ يَغْدُوَ أَحَدُكُمْ كُلَّ يَوْمٍ إِلَى الْمَسْجِدِ فَيَتَعَلَّمَ آيَتَيْنِ مِنْ كِتَابِ اللَّهِ عَزَّ وَجَلَّ خَيْرٌ لَهُ مِنْ نَاقَتَيْنِ وَإِنْ ثَلاَثٌ فَثَلاَثٌ مِثْلُ أَعْدَادِهِنَّ مِنَ الإِبِلِ ‏"‏ ‏.‏\hadithno{1456}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (803)}\hadithtrans{Uqbah b. 'Amir al-Juhani said:When we were in the Suffah, the Messenger of Allah (ﷺ) asked: Which of you would like to go out every morning to Buthan or Al-'Aqiq and bring two large humped and fat she-camels without being guilty of sin and severing ties of relationship ? They (the people) said: Messenger of Allah, we would all like that. He said: If any one of you goes out in the morning to the mosque and learns two verses of the Book of Allah, the Exalted, it is better for him than two she-camels, and three verses are better for him than three she-camels, and so on than their numbers in camels}}
\hadithdefcmd{abudawud}{1457}{حَدَّثَنَا أَحْمَدُ بْنُ أَبِي شُعَيْبٍ الْحَرَّانِيُّ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنِ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ ‏\{‏ الْحَمْدُ لِلَّهِ رَبِّ الْعَالَمِينَ ‏\}‏ أُمُّ الْقُرْآنِ وَأُمُّ الْكِتَابِ وَالسَّبْعُ الْمَثَانِي ‏"‏ ‏.‏\hadithno{1457}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (4704)}\hadithtrans{Abu Hurairah reported the Messenger of Allah (ﷺ) as saying:All praise be to Allah, the Lord of the Universe" (1) is the epitome or basis of the Qur'an, the epitome or basis of the Book, and the seven oft-repeated verses}}
\hadithdefcmd{abudawud}{1458}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا خَالِدٌ، حَدَّثَنَا شُعْبَةُ، عَنْ خُبَيْبِ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ سَمِعْتُ حَفْصَ بْنَ عَاصِمٍ، يُحَدِّثُ عَنْ أَبِي سَعِيدِ بْنِ الْمُعَلَّى، أَنَّ النَّبِيَّ صلى الله عليه وسلم مَرَّ بِهِ وَهُوَ يُصَلِّي فَدَعَاهُ قَالَ فَصَلَّيْتُ ثُمَّ أَتَيْتُهُ قَالَ فَقَالَ ‏"‏ مَا مَنَعَكَ أَنْ تُجِيبَنِي ‏"‏ ‏.‏ قَالَ كُنْتُ أُصَلِّي ‏.‏ قَالَ ‏"‏ أَلَمْ يَقُلِ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ يَا أَيُّهَا الَّذِينَ آمَنُوا اسْتَجِيبُوا لِلَّهِ وَلِلرَّسُولِ إِذَا دَعَاكُمْ لِمَا يُحْيِيكُمْ ‏\}‏ لأُعَلِّمَنَّكَ أَعْظَمَ سُورَةٍ مِنَ الْقُرْآنِ أَوْ فِي الْقُرْآنِ ‏"‏ ‏.‏ شَكَّ خَالِدٌ ‏"‏ قَبْلَ أَنْ أَخْرُجَ مِنَ الْمَسْجِدِ ‏"‏ ‏.‏ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ قَوْلَكَ ‏.‏ قَالَ ‏"‏ ‏\{‏ الْحَمْدُ لِلَّهِ رَبِّ الْعَالَمِينَ ‏\}‏ وَهِيَ السَّبْعُ الْمَثَانِي الَّتِي أُوتِيتُ وَالْقُرْآنُ الْعَظِيمُ ‏"‏ ‏.‏\hadithno{1458}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (4474)}\hadithtrans{Abu Sa'id b. al-Mu'alla said that when he was praying the Prophet (ﷺ) passed by him and he called him. He said:I prayed ant then I came to him. He asked: What prevented you from answering me ? He replied: I was praying. He said: Has not Allah said: "O you who believe, respond to Allah and the Apostle when he calls you to that which gives you life ? (8:24) Let me teach you the greatest surah from the Qur'an or in the Qur'an (the narrator Khalid doubted) before I leave the mosque. I said: (I shall memorize) your saying. He said: It is: "Praise be to Allah, the Lord of the Universe" which is the seven oft-repeated verses, and the mighty Qur'an}}
\hadithdefcmd{abudawud}{1459}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ مُسْلِمٍ الْبَطِينِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أُوتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم سَبْعًا مِنَ الْمَثَانِي الطُّوَلِ وَأُوتِيَ مُوسَى عَلَيْهِ السَّلاَمُ سِتًّا فَلَمَّا أَلْقَى الأَلْوَاحَ رُفِعَتْ ثِنْتَانِ وَبَقِيَ أَرْبَعٌ ‏.‏\hadithno{1459}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Muquf; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: The Messenger of Allah (ﷺ) was given seven repeated long surahs, while Moses was given six, When he threw the tablets, two of them were withdrawn and four remained}}
\hadithdefcmd{abudawud}{1460}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا سَعِيدُ بْنُ إِيَاسٍ، عَنْ أَبِي السَّلِيلِ، عَنْ عَبْدِ اللَّهِ بْنِ رَبَاحٍ الأَنْصَارِيِّ، عَنْ أُبَىِّ بْنِ كَعْبٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَبَا الْمُنْذِرِ أَىُّ آيَةٍ مَعَكَ مِنْ كِتَابِ اللَّهِ أَعْظَمُ ‏"‏ ‏.‏ قَالَ قُلْتُ اللَّهُ وَرَسُولُهُ أَعْلَمُ ‏.‏ قَالَ ‏"‏ أَبَا الْمُنْذِرِ أَىُّ آيَةٍ مَعَكَ مِنْ كِتَابِ اللَّهِ أَعْظَمُ ‏"‏ ‏.‏ قَالَ قُلْتُ ‏\{‏ اللَّهُ لاَ إِلَهَ إِلاَّ هُوَ الْحَىُّ الْقَيُّومُ ‏\}‏ قَالَ فَضَرَبَ فِي صَدْرِي وَقَالَ ‏"‏ لِيَهْنِ لَكَ يَا أَبَا الْمُنْذِرِ الْعِلْمُ ‏"‏ ‏.‏\hadithno{1460}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (810)}\hadithtrans{Ubayy b. Ka'b said:The Messenger of Allah (ﷺ) said: Abu al-Mundhir, which verse of Allah's Book that you have is creates ? I replied: Allah and His Apostle know best. He said: Abu al-Mundhir, which verse of Allah's that you have is greatest ? I said: Allah, there is no god but He, the Living, the Eternal. Thereupon he struck me on the beast and said: May knowledge be pleasant for you, Abu al-Mundhir}}
\hadithdefcmd{abudawud}{1461}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَجُلاً، سَمِعَ رَجُلاً، يَقْرَأُ ‏\{‏ قُلْ هُوَ اللَّهُ أَحَدٌ ‏\}‏ يُرَدِّدُهَا فَلَمَّا أَصْبَحَ جَاءَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ ذَلِكَ لَهُ وَكَانَ الرَّجُلُ يَتَقَالُّهَا فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ إِنَّهَا لَتَعْدِلُ ثُلُثَ الْقُرْآنِ ‏"‏ ‏.‏\hadithno{1461}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5013)}\hadithtrans{Abu Sa'id al-Khudri said:A man heard another man reciting "Say, He is Allah, One" He was repeating it. When the next morning came, he went to the Messenger of Allah (ﷺ) and mentioned to him. The man tool it (this surah) as a small one. The Prophet (ﷺ) said: By Him in Whose Hand is my life, it is equivalent to a third of the Qur'an}}
\hadithdefcmd{abudawud}{1462}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي مُعَاوِيَةُ، عَنِ الْعَلاَءِ بْنِ الْحَارِثِ، عَنِ الْقَاسِمِ، مَوْلَى مُعَاوِيَةَ عَنْ عُقْبَةَ بْنِ عَامِرٍ، قَالَ كُنْتُ أَقُودُ بِرَسُولِ اللَّهِ صلى الله عليه وسلم نَاقَتَهُ فِي السَّفَرِ فَقَالَ لِي ‏"‏ يَا عُقْبَةُ أَلاَ أُعَلِّمُكَ خَيْرَ سُورَتَيْنِ قُرِئَتَا ‏"‏ ‏.‏ فَعَلَّمَنِي ‏\{‏ قُلْ أَعُوذُ بِرَبِّ الْفَلَقِ ‏\}‏ وَ ‏\{‏ قُلْ أَعُوذُ بِرَبِّ النَّاسِ ‏\}‏ قَالَ فَلَمْ يَرَنِي سُرِرْتُ بِهِمَا جِدًّا فَلَمَّا نَزَلَ لِصَلاَةِ الصُّبْحِ صَلَّى بِهِمَا صَلاَةَ الصُّبْحِ لِلنَّاسِ فَلَمَّا فَرَغَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنَ الصَّلاَةِ الْتَفَتَ إِلَىَّ فَقَالَ ‏"‏ يَا عُقْبَةُ كَيْفَ رَأَيْتَ ‏"‏ ‏.‏\hadithno{1462}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Uqbah ibn Amir: I was driving the she-camel of the Messenger of Allah (ﷺ) during a journey. He said to me: Uqbah, should I not teach you two best surahs ever recited? He then taught me: "Say, I seek refuge in the Lord of the dawn," and "Say, I seek refuge in the Lord of men." He did not see me much pleased (by these two surahs). When he alighted for prayer, he led the people in the morning prayer and recited them in prayer. When the Messenger of Allah (ﷺ) finished his prayer, he turned to me and said: O Uqbah, how did you see}}
\hadithdefcmd{abudawud}{1463}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِيهِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، قَالَ بَيْنَا أَنَا أَسِيرُ، مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بَيْنَ الْجُحْفَةِ وَالأَبْوَاءِ إِذْ غَشِيَتْنَا رِيحٌ وَظُلْمَةٌ شَدِيدَةٌ فَجَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَتَعَوَّذُ بِـ ‏\{‏ أَعُوذُ بِرَبِّ الْفَلَقِ ‏\}‏ وَ ‏\{‏ أَعُوذُ بِرَبِّ النَّاسِ ‏\}‏ وَيَقُولُ ‏"‏ يَا عُقْبَةُ تَعَوَّذْ بِهِمَا فَمَا تَعَوَّذَ مُتَعَوِّذٌ بِمِثْلِهِمَا ‏"‏ ‏.‏ قَالَ وَسَمِعْتُهُ يَؤُمُّنَا بِهِمَا فِي الصَّلاَةِ ‏.‏\hadithno{1463}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Uqbah ibn Amir: White I was travelling with the Messenger of Allah (ﷺ) between al-Juhfah and al-Abwa', a wind and intense darkness enveloped us, whereupon the Messenger of Allah (ﷺ) began to seek refuge in Allah, reciting: "I seek refuge in the Lord of the dawn," and "I seek refuge in the Lord of men." He then said: Uqbah, use them when seeking refuge in Allah, for no one can use anything to compare with them for the purpose. Uqbah added: I heard him reciting them when he led the people in prayer}}
\hadithdefcmd{abudawud}{1464}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، حَدَّثَنِي عَاصِمُ بْنُ بَهْدَلَةَ، عَنْ زِرٍّ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يُقَالُ لِصَاحِبِ الْقُرْآنِ اقْرَأْ وَارْتَقِ وَرَتِّلْ كَمَا كُنْتَ تُرَتِّلُ فِي الدُّنْيَا فَإِنَّ مَنْزِلَكَ عِنْدَ آخِرِ آيَةٍ تَقْرَؤُهَا ‏"‏ ‏.‏\hadithno{1464}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: The Messenger of Allah (ﷺ) said: One who was devoted to the Qur'an will be told to recite, ascend and recite carefully as he recited carefully when he was in the world, for he will reach his abode when he comes to the last verse he recites}}
\hadithdefcmd{abudawud}{1465}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا جَرِيرٌ، عَنْ قَتَادَةَ، قَالَ سَأَلْتُ أَنَسًا عَنْ قِرَاءَةِ النَّبِيِّ، صلى الله عليه وسلم فَقَالَ كَانَ يَمُدُّ مَدًّا ‏.‏\hadithno{1465}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5045)}\hadithtrans{Qatadah said:I asked Anas about the recitation of the Qur'an by the Prophet (ﷺ). He said: He used to express all the long accents clearly}}
\hadithdefcmd{abudawud}{1466}{حَدَّثَنَا يَزِيدُ بْنُ خَالِدِ بْنِ مَوْهَبٍ الرَّمْلِيُّ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ يَعْلَى بْنِ مَمْلَكٍ، أَنَّهُ سَأَلَ أُمَّ سَلَمَةَ عَنْ قِرَاءَةِ، رَسُولِ اللَّهِ صلى الله عليه وسلم وَصَلاَتِهِ فَقَالَتْ وَمَا لَكُمْ وَصَلاَتَهُ كَانَ يُصَلِّي وَيَنَامُ قَدْرَ مَا صَلَّى ثُمَّ يُصَلِّي قَدْرَ مَا نَامَ ثُمَّ يَنَامُ قَدْرَ مَا صَلَّى حَتَّى يُصْبِحَ وَنَعَتَتْ قِرَاءَتَهُ فَإِذَا هِيَ تَنْعَتُ قِرَاءَتَهُ حَرْفًا حَرْفًا ‏.‏\hadithno{1466}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Umm Salamah, Ummul Mu'minin: Ya'la ibn Mumallak said that he asked Umm Salamah about the recitation and prayer of the Messenger of Allah (ﷺ). She said: What have you to do with his prayer? He would pray, then sleep as long as he had prayed, till morning. She then described his recitation and did so with an exposition word by word}}
\hadithdefcmd{abudawud}{1467}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ مُعَاوِيَةَ بْنِ قُرَّةَ، عَنْ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَوْمَ فَتْحِ مَكَّةَ وَهُوَ عَلَى نَاقَةٍ يَقْرَأُ بِسُورَةِ الْفَتْحِ وَهُوَ يُرَجِّعُ ‏.‏\hadithno{1467}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (7540) Sahih Muslim (794)}\hadithtrans{Abd Allah b. Mughaffal said:On the day of the Conquest of Mecca I saw the Messenger of Allah (ﷺ) riding his she-camel reciting Surah al-Fath repeating each verse several times}}
\hadithdefcmd{abudawud}{1468}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ طَلْحَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَوْسَجَةَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ زَيِّنُوا الْقُرْآنَ بِأَصْوَاتِكُمْ ‏"‏ ‏.‏\hadithno{1468}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Al-Bara' ibn Azib: The Prophet (ﷺ) said: Beautify the Qur'an with your voices}}
\hadithdefcmd{abudawud}{1469}{حَدَّثَنَا أَبُو الْوَلِيدِ الطَّيَالِسِيُّ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، وَيَزِيدُ بْنُ خَالِدِ بْنِ مَوْهَبٍ الرَّمْلِيُّ، بِمَعْنَاهُ أَنَّ اللَّيْثَ، حَدَّثَهُمْ عَنْ عَبْدِ اللَّهِ بْنِ أَبِي مُلَيْكَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي نَهِيكٍ، عَنْ سَعْدِ بْنِ أَبِي وَقَّاصٍ، - وَقَالَ يَزِيدُ عَنِ ابْنِ أَبِي مُلَيْكَةَ، - عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، وَقَالَ، قُتَيْبَةُ هُوَ فِي كِتَابِي عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، - قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَيْسَ مِنَّا مَنْ لَمْ يَتَغَنَّ بِالْقُرْآنِ ‏"‏ ‏.‏\hadithno{1469}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Sa'd ibn AbuWaqqas: (The narrator Qutaibah said: This tradition has been narrated by Sa'id b. Abu Sa'id in my collection): The Messenger of Allah (ﷺ) said: He who does not chant the Qur'an is not one of us}}
\hadithdefcmd{abudawud}{1470}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرٍو، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي نَهِيكٍ، عَنْ سَعْدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِثْلَهُ ‏.‏\hadithno{1470}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{This tradition has also been transmitted by Sa'd (b. Abi Waqqas) from the Prophet (ﷺ) in a similar manner through a different chain of narrators}}
\hadithdefcmd{abudawud}{1471}{حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ حَمَّادٍ، حَدَّثَنَا عَبْدُ الْجَبَّارِ بْنُ الْوَرْدِ، قَالَ سَمِعْتُ ابْنَ أَبِي مُلَيْكَةَ، يَقُولُ قَالَ عُبَيْدُ اللَّهِ بْنُ أَبِي يَزِيدَ مَرَّ بِنَا أَبُو لُبَابَةَ فَاتَّبَعْنَاهُ حَتَّى دَخَلَ بَيْتَهُ فَدَخَلْنَا عَلَيْهِ فَإِذَا رَجُلٌ رَثُّ الْبَيْتِ رَثُّ الْهَيْئَةِ فَسَمِعْتُهُ يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لَيْسَ مِنَّا مَنْ لَمْ يَتَغَنَّ بِالْقُرْآنِ ‏"‏ ‏.‏ قَالَ فَقُلْتُ لاِبْنِ أَبِي مُلَيْكَةَ يَا أَبَا مُحَمَّدٍ أَرَأَيْتَ إِذَا لَمْ يَكُنْ حَسَنَ الصَّوْتِ قَالَ يُحَسِّنُهُ مَا اسْتَطَاعَ ‏.‏\hadithno{1471}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuLubabah: Ubaydullah ibn Yazid said: AbuLubabah passed by us and we followed him till he entered his house, and we also entered it. There was a man in a rusty house and in shabby condition. I heard him say: I heard the Messenger of Allah (ﷺ) say: He is not one of us who does not chant the Qur'an. I (the narrator AbdulJabbar) said to Ibn AbuMulaykah: AbuMuhammad, what do you think if a person does not have pleasant voice? He said: He should recite with pleasant voice as much as possible}}
\hadithdefcmd{abudawud}{1472}{حَدَّثَنَا مُحَمَّدُ بْنُ سُلَيْمَانَ الأَنْبَارِيُّ، قَالَ قَالَ وَكِيعٌ وَابْنُ عُيَيْنَةَ يَعْنِي يَسْتَغْنِي بِهِ ‏.‏\hadithno{1472}\hadithgrade{Al-Albani: Sahih Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Maqtu; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Waki' and Ibn 'Uyainah said (explaining the meaning of taghanni):This means that the Qur'an makes a man neglect all other things, and be content with it}}
\hadithdefcmd{abudawud}{1473}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْمَهْرِيُّ، أَخْبَرَنَا ابْنُ وَهْبٍ، حَدَّثَنِي عُمَرُ بْنُ مَالِكٍ، وَحَيْوَةُ، عَنِ ابْنِ الْهَادِ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ بْنِ الْحَارِثِ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَا أَذِنَ اللَّهُ لِشَىْءٍ مَا أَذِنَ لِنَبِيٍّ حَسَنِ الصَّوْتِ يَتَغَنَّى بِالْقُرْآنِ يَجْهَرُ بِهِ ‏"‏ ‏.‏\hadithno{1473}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (7544) Sahih Muslim (792)}\hadithtrans{Abu Hurairah reported the Messenger of Allah (ﷺ) as saying:Allah has not listened to anything as He does to a Prophet chanting the Qur'an with a loud voice}}
\hadithdefcmd{abudawud}{1474}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، أَخْبَرَنَا ابْنُ إِدْرِيسَ، عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ، عَنْ عِيسَى بْنِ فَائِدٍ، عَنْ سَعْدِ بْنِ عُبَادَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا مِنِ امْرِئٍ يَقْرَأُ الْقُرْآنَ يَنْسَاهُ إِلاَّ لَقِيَ اللَّهَ عَزَّ وَجَلَّ يَوْمَ الْقِيَامَةِ أَجْذَمَ ‏"‏ ‏.‏\hadithno{1474}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Sa'd ibn Ubadah: The Prophet (ﷺ) said: No man recites the Qur'an, then forgets it, but will meet Allah on the Day of Judgment in a maimed condition (or empty-handed, or with no excuse)}}
\hadithdefcmd{abudawud}{1475}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدٍ الْقَارِيِّ، قَالَ سَمِعْتُ عُمَرَ بْنَ الْخَطَّابِ، يَقُولُ سَمِعْتُ هِشَامَ بْنَ حَكِيمِ بْنِ حِزَامٍ، يَقْرَأُ سُورَةَ الْفُرْقَانِ عَلَى غَيْرِ مَا أَقْرَؤُهَا وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَقْرَأَنِيهَا فَكِدْتُ أَنْ أَعْجَلَ عَلَيْهِ ثُمَّ أَمْهَلْتُهُ حَتَّى انْصَرَفَ ثُمَّ لَبَّبْتُهُ بِرِدَائِهِ فَجِئْتُ بِهِ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ إِنِّي سَمِعْتُ هَذَا يَقْرَأُ سُورَةَ الْفُرْقَانِ عَلَى غَيْرِ مَا أَقْرَأْتَنِيهَا ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اقْرَأْ ‏"‏ ‏.‏ فَقَرَأَ الْقِرَاءَةَ الَّتِي سَمِعْتُهُ يَقْرَأُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَكَذَا أُنْزِلَتْ ‏"‏ ‏.‏ ثُمَّ قَالَ لِي ‏"‏ اقْرَأْ ‏"‏ ‏.‏ فَقَرَأْتُ فَقَالَ ‏"‏ هَكَذَا أُنْزِلَتْ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ إِنَّ هَذَا الْقُرْآنَ أُنْزِلَ عَلَى سَبْعَةِ أَحْرُفٍ فَاقْرَءُوا مَا تَيَسَّرَ مِنْهُ ‏"‏ ‏.‏\hadithno{1475}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2419) Sahih Muslim (818)}\hadithtrans{Umar b. al-Khattab said:I heard Hisham b. Hakim (b. Hizam) reciting Surah al-Furqan in a different manner from my way of reciting, and the Messenger of Allah (ﷺ) had taught me to recite it. I nearly spoke sharply to him, but I delayed till he had finished. Then I caught his cloak at the neck, and I brought him to the Messenger of Allah (ﷺ). I said: Messenger of Allah, I heard this man reciting Surah al-Furqan in a manner different from that in which you taught me to recite it. The Messenger of Allah (ﷺ) the told him to recite it. He then recited in the manner I heard him recite. The Messenger of Allah (ﷺ) said: Thus was it sent down. He then said to me: Recite, I recited (it). He then said: Thus was it sent down. He said: The Qur'an was sent down in seven modes of reading, so recite according to what comes most easily}}
\hadithdefcmd{abudawud}{1476}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، قَالَ قَالَ الزُّهْرِيُّ إِنَّمَا هَذِهِ الأَحْرُفُ فِي الأَمْرِ الْوَاحِدِ لَيْسَ تَخْتَلِفُ فِي حَلاَلٍ وَلاَ حَرَامٍ ‏.‏\hadithno{1476}\hadithgrade{Al-Albani: Sahih Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Maqtu; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Al-Zuhri said:These modes of reading aimed at the same point, not different in respect of lawful and unlawful}}
\hadithdefcmd{abudawud}{1477}{حَدَّثَنَا أَبُو الْوَلِيدِ الطَّيَالِسِيُّ، حَدَّثَنَا هَمَّامُ بْنُ يَحْيَى، عَنْ قَتَادَةَ، عَنْ يَحْيَى بْنِ يَعْمُرَ، عَنْ سُلَيْمَانَ بْنِ صُرَدٍ الْخُزَاعِيِّ، عَنْ أُبَىِّ بْنِ كَعْبٍ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ يَا أُبَىُّ إِنِّي أُقْرِئْتُ الْقُرْآنَ فَقِيلَ لِي عَلَى حَرْفٍ أَوْ حَرْفَيْنِ فَقَالَ الْمَلَكُ الَّذِي مَعِي قُلْ عَلَى حَرْفَيْنِ ‏.‏ قُلْتُ عَلَى حَرْفَيْنِ ‏.‏ فَقِيلَ لِي عَلَى حَرْفَيْنِ أَوْ ثَلاَثَةٍ ‏.‏ فَقَالَ الْمَلَكُ الَّذِي مَعِي قُلْ عَلَى ثَلاَثَةٍ ‏.‏ قُلْتُ عَلَى ثَلاَثَةٍ ‏.‏ حَتَّى بَلَغَ سَبْعَةَ أَحْرُفٍ ثُمَّ قَالَ لَيْسَ مِنْهَا إِلاَّ شَافٍ كَافٍ إِنْ قُلْتَ سَمِيعًا عَلِيمًا عَزِيزًا حَكِيمًا مَا لَمْ تَخْتِمْ آيَةَ عَذَابٍ بِرَحْمَةٍ أَوْ آيَةَ رَحْمَةٍ بِعَذَابٍ ‏"‏ ‏.‏\hadithno{1477}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Ubayy b. Ka'b reported:The Prophet (ﷺ) said: "Ubayy, I was asked to recite the Qur'an and I was asked: 'In one mode or two modes?' The angel that accompanied me said: 'Say, in two modes', I said: 'In two modes', I was asked again: 'In two or three modes'. The matter reached up to seven modes. He then said: 'Each mode is sufficiently health-giving, whether you utter 'all-hearing and all-knowing' or instead 'all-powerful and all-wise'. This is valid until you finish the verse indicating punishment on mercy and finish the verse indicating mercy on punishment}}
\hadithdefcmd{abudawud}{1478}{حَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ أَبِي لَيْلَى، عَنْ أُبَىِّ بْنِ كَعْبٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ عِنْدَ أَضَاةِ بَنِي غِفَارٍ فَأَتَاهُ جِبْرِيلُ صلى الله عليه وسلم فَقَالَ إِنَّ اللَّهَ عَزَّ وَجَلَّ يَأْمُرُكَ أَنْ تُقْرِئَ أُمَّتَكَ عَلَى حَرْفٍ ‏.‏ قَالَ ‏ "‏ أَسْأَلُ اللَّهَ مُعَافَاتَهُ وَمَغْفِرَتَهُ إِنَّ أُمَّتِي لاَ تُطِيقُ ذَلِكَ ‏"‏ ‏.‏ ثُمَّ أَتَاهُ ثَانِيَةً فَذَكَرَ نَحْوَ هَذَا حَتَّى بَلَغَ سَبْعَةَ أَحْرُفٍ قَالَ إِنَّ اللَّهَ يَأْمُرُكَ أَنْ تُقْرِئَ أُمَّتَكَ عَلَى سَبْعَةِ أَحْرُفٍ فَأَيُّمَا حَرْفٍ قَرَءُوا عَلَيْهِ فَقَدْ أَصَابُوا ‏.‏\hadithno{1478}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (821)}\hadithtrans{Ubayy b. Ka'b said:The Prophet (ﷺ) was present at the pool of Banu Ghifar, Gabriel came to him and said: "Allah has commanded you to make your community read (the Qur'an) in one harf. He (the Prophet) said: 'I beg Allah His pardon and forgiveness; my community has not strength to do so'. He then came for the second time and told him the same thing till he reached up to seven harfs. Finally, he said: 'Allah has commanded you to make your community read (the Qur'an) in seven harfs; in whichever mode they read, that will be correct}}
\hadithdefcmd{abudawud}{1479}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، عَنْ ذَرٍّ، عَنْ يُسَيْعٍ الْحَضْرَمِيِّ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ الدُّعَاءُ هُوَ الْعِبَادَةُ ‏\{‏ قَالَ رَبُّكُمُ ادْعُونِي أَسْتَجِبْ لَكُمْ ‏\}‏ ‏"‏ ‏.‏\hadithno{1479}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated An-Nu'man ibn Bashir: The Prophet (ﷺ) said: Supplication (du'a') is itself the worship. (He then recited:) "And your Lord said: Call on Me, I will answer you" (xI)}}
\hadithdefcmd{abudawud}{1480}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، عَنْ زِيَادِ بْنِ مِخْرَاقٍ، عَنْ أَبِي نُعَامَةَ، عَنِ ابْنٍ لِسَعْدٍ، أَنَّهُ قَالَ سَمِعَنِي أَبِي، وَأَنَا أَقُولُ اللَّهُمَّ، إِنِّي أَسْأَلُكَ الْجَنَّةَ وَنَعِيمَهَا وَبَهْجَتَهَا وَكَذَا وَكَذَا وَأَعُوذُ بِكَ مِنَ النَّارِ وَسَلاَسِلِهَا وَأَغْلاَلِهَا وَكَذَا وَكَذَا فَقَالَ يَا بُنَىَّ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ سَيَكُونُ قَوْمٌ يَعْتَدُونَ فِي الدُّعَاءِ ‏"‏ ‏.‏ فَإِيَّاكَ أَنْ تَكُونَ مِنْهُمْ إِنْ أُعْطِيتَ الْجَنَّةَ أُعْطِيتَهَا وَمَا فِيهَا مِنَ الْخَيْرِ وَإِنْ أُعِذْتَ مِنَ النَّارِ أُعِذْتَ مِنْهَا وَمَا فِيهَا مِنَ الشَّرِّ ‏.‏\hadithno{1480}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Sa'd ibn AbuWaqqas: Ibn Sa'd said: My father (Sa'd ibn AbuWaqqas) heard me say: O Allah, I ask Thee for Paradise, its blessings, its pleasure and such-and-such, and such-and-such; I seek refuge in Thee from Hell, from its chains, from its collars, and from such-and-such, and from such-and-such. He said: I heard the Messenger of Allah (ﷺ) say: There will be people who will exaggerate in supplication. You should not be one of them. If you are granted Paradise, you will be granted all what is good therein; if you are protected from Hell, you will be protected from what is evil therein}}
\hadithdefcmd{abudawud}{1481}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ، حَدَّثَنَا حَيْوَةُ، أَخْبَرَنِي أَبُو هَانِئٍ، حُمَيْدُ بْنُ هَانِئٍ أَنَّ أَبَا عَلِيٍّ، عَمْرَو بْنَ مَالِكٍ حَدَّثَهُ أَنَّهُ، سَمِعَ فَضَالَةَ بْنَ عُبَيْدٍ، صَاحِبَ رَسُولِ اللَّهِ صلى الله عليه وسلم يَقُولُ سَمِعَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَجُلاً يَدْعُو فِي صَلاَتِهِ لَمْ يُمَجِّدِ اللَّهَ تَعَالَى وَلَمْ يُصَلِّ عَلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ عَجِلَ هَذَا ‏"‏ ‏.‏ ثُمَّ دَعَاهُ فَقَالَ لَهُ أَوْ لِغَيْرِهِ ‏"‏ إِذَا صَلَّى أَحَدُكُمْ فَلْيَبْدَأْ بِتَحْمِيدِ رَبِّهِ جَلَّ وَعَزَّ وَالثَّنَاءِ عَلَيْهِ ثُمَّ يُصَلِّي عَلَى النَّبِيِّ صلى الله عليه وسلم ثُمَّ يَدْعُو بَعْدُ بِمَا شَاءَ ‏"‏ ‏.‏\hadithno{1481}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Fudalah ibn Ubayd,: The Messenger of Allah (ﷺ) heard a person supplicating during prayer. He did not mention the greatness of Allah, nor did he invoke blessings on the Prophet (ﷺ). The Messenger of Allah (ﷺ) said: He made haste. He then called him and said either to him or to any other person: If any of you prays, he should mention the exaltation of his Lord in the beginning and praise Him; he should then invoke blessings on the Prophet (ﷺ); thereafter he should supplicate Allah for anything he wishes}}
\hadithdefcmd{abudawud}{1482}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنِ الأَسْوَدِ بْنِ شَيْبَانَ، عَنْ أَبِي نَوْفَلٍ، عَنْ عَائِشَةَ، رضى الله عنها قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَسْتَحِبُّ الْجَوَامِعَ مِنَ الدُّعَاءِ وَيَدَعُ مَا سِوَى ذَلِكَ ‏.‏\hadithno{1482}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Aishah said:The Messenger of Allah (ﷺ) liked comprehensive supplication and abandoned other kinds}}
\hadithdefcmd{abudawud}{1483}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَقُولَنَّ أَحَدُكُمُ اللَّهُمَّ اغْفِرْ لِي إِنْ شِئْتَ اللَّهُمَّ ارْحَمْنِي إِنْ شِئْتَ لِيَعْزِمِ الْمَسْأَلَةَ فَإِنَّهُ لاَ مُكْرِهَ لَهُ ‏"‏ ‏.‏\hadithno{1483}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6339)}\hadithtrans{Abu Hurairah reported the Messenger of Allah (ﷺ) as saying:"One of you should not say (in his supplication): O Allah, forgive me if You please, show mercy to me if You please.' Rather, be firm in your asking, for no one can force Him}}
\hadithdefcmd{abudawud}{1484}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي عُبَيْدٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يُسْتَجَابُ لأَحَدِكُمْ مَا لَمْ يَعْجَلْ فَيَقُولُ قَدْ دَعَوْتُ فَلَمْ يُسْتَجَبْ لِي ‏"‏ ‏.‏\hadithno{1484}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6340) Sahih Muslim (2735)}\hadithtrans{Abu Hurairah reported the Messenger of Allah (ﷺ) as saying:"One of you is granted an answer (to his supplication) provided he does not say: 'I prayed but I was not granted an answer}}
\hadithdefcmd{abudawud}{1485}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ مُحَمَّدِ بْنِ أَيْمَنَ، عَنْ عَبْدِ اللَّهِ بْنِ يَعْقُوبَ بْنِ إِسْحَاقَ، عَمَّنْ حَدَّثَهُ عَنْ مُحَمَّدِ بْنِ كَعْبٍ الْقُرَظِيِّ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَسْتُرُوا الْجُدُرَ مَنْ نَظَرَ فِي كِتَابِ أَخِيهِ بِغَيْرِ إِذْنِهِ فَإِنَّمَا يَنْظُرُ فِي النَّارِ سَلُوا اللَّهَ بِبُطُونِ أَكُفِّكُمْ وَلاَ تَسْأَلُوهُ بِظُهُورِهَا فَإِذَا فَرَغْتُمْ فَامْسَحُوا بِهَا وُجُوهَكُمْ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ وَجْهٍ عَنْ مُحَمَّدِ بْنِ كَعْبٍ كُلُّهَا وَاهِيَةٌ وَهَذَا الطَّرِيقُ أَمْثَلُهَا وَهُوَ ضَعِيفٌ أَيْضًا ‏.‏\hadithno{1485}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) said: Do not cover the walls. He who sees the letter of his brother without his permission, sees Hell-fire. Supplicate Allah with the palms of your hands; do not supplicate Him with their backs upwards. When you finish supplication, wipe your faces with them. Abu Dawud said: This tradition has been transmitted through a different chains by Muhammad b. Ka'b; all of them are weak. The chain I have narrated is best of them; but it is also weak}}
\hadithdefcmd{abudawud}{1486}{حَدَّثَنَا سُلَيْمَانُ بْنُ عَبْدِ الْحَمِيدِ الْبَهْرَانِيُّ، قَالَ قَرَأْتُهُ فِي أَصْلِ إِسْمَاعِيلَ - يَعْنِي ابْنَ عَيَّاشٍ - حَدَّثَنِي ضَمْضَمٌ عَنْ شُرَيْحٍ حَدَّثَنَا أَبُو ظَبْيَةَ أَنَّ أَبَا بَحْرِيَّةَ السَّكُونِيَّ حَدَّثَهُ عَنْ مَالِكِ بْنِ يَسَارٍ السَّكُونِيِّ ثُمَّ الْعَوْفِيِّ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا سَأَلْتُمُ اللَّهَ فَاسْأَلُوهُ بِبُطُونِ أَكُفِّكُمْ وَلاَ تَسْأَلُوهُ بِظُهُورِهَا ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ سُلَيْمَانُ بْنُ عَبْدِ الْحَمِيدِ لَهُ عِنْدَنَا صُحْبَةٌ يَعْنِي مَالِكَ بْنَ يَسَارٍ ‏.‏\hadithno{1486}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Malik ibn Yasar as-Sakuni, al-Awfi: The Prophet (ﷺ) said: When you make requests to Allah, do so with the palms of your hands, and not backs, upwards. Abu Dawud said: The narrator Sulaiman b. 'Abd al-Hamid said: according to us Malik b. Yasar was a Companion of the Prophet (ﷺ)}}
\hadithdefcmd{abudawud}{1487}{حَدَّثَنَا عُقْبَةُ بْنُ مُكْرَمٍ، حَدَّثَنَا سَلْمُ بْنُ قُتَيْبَةَ، عَنْ عُمَرَ بْنِ نَبْهَانَ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَدْعُو هَكَذَا بِبَاطِنِ كَفَّيْهِ وَظَاهِرِهِمَا ‏.‏\hadithno{1487}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas ibn Malik: I saw the Messenger of Allah (ﷺ) supplicating Allah in this manner with the palms of his hands and also with their backs upwards}}
\hadithdefcmd{abudawud}{1488}{حَدَّثَنَا مُؤَمَّلُ بْنُ الْفَضْلِ الْحَرَّانِيُّ، حَدَّثَنَا عِيسَى، - يَعْنِي ابْنَ يُونُسَ - حَدَّثَنَا جَعْفَرٌ، - يَعْنِي ابْنَ مَيْمُونٍ صَاحِبَ الأَنْمَاطِ - حَدَّثَنِي أَبُو عُثْمَانَ، عَنْ سَلْمَانَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ رَبَّكُمْ تَبَارَكَ وَتَعَالَى حَيِيٌّ كَرِيمٌ يَسْتَحْيِي مِنْ عَبْدِهِ إِذَا رَفَعَ يَدَيْهِ إِلَيْهِ أَنْ يَرُدَّهُمَا صِفْرًا ‏"‏ ‏.‏\hadithno{1488}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Salman al-Farsi: The Prophet (ﷺ) said: Your Lord is munificent and generous, and is ashamed to turn away empty the hands of His servant when he raises them to Him}}
\hadithdefcmd{abudawud}{1489}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، - يَعْنِي ابْنَ خَالِدٍ - حَدَّثَنِي الْعَبَّاسُ بْنُ عَبْدِ اللَّهِ بْنِ مَعْبَدِ بْنِ الْعَبَّاسِ بْنِ عَبْدِ الْمُطَّلِبِ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ الْمَسْأَلَةُ أَنْ تَرْفَعَ، يَدَيْكَ حَذْوَ مَنْكِبَيْكَ أَوْ نَحْوَهُمَا وَالاِسْتِغْفَارُ أَنْ تُشِيرَ بِأُصْبُعٍ وَاحِدَةٍ وَالاِبْتِهَالُ أَنْ تَمُدَّ يَدَيْكَ جَمِيعًا ‏.‏\hadithno{1489}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Muquf; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: Ikrimah quoted Ibn Abbas as saying: When asking for something you should raise your hands opposite to your shoulders; when asking for forgiveness you should point with one finger; and when making an earnest supplication you should spread out both your hands}}
\hadithdefcmd{abudawud}{1490}{حَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنِي عَبَّاسُ بْنُ عَبْدِ اللَّهِ بْنِ مَعْبَدِ بْنِ عَبَّاسٍ، بِهَذَا الْحَدِيثِ قَالَ فِيهِ وَالاِبْتِهَالُ هَكَذَا وَرَفَعَ يَدَيْهِ وَجَعَلَ ظُهُورَهُمَا مِمَّا يَلِي وَجْهَهُ ‏.‏\hadithno{1490}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Muquf; Zubair Ali Zai: Hasan}\hadithtrans{In another version Ibn 'Abbas said:Earnest supplication should be made like this: he raised his hand and made his palms in the direction of his face}}
\hadithdefcmd{abudawud}{1491}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ حَمْزَةَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنِ الْعَبَّاسِ بْنِ عَبْدِ اللَّهِ بْنِ مَعْبَدِ بْنِ عَبَّاسٍ، عَنْ أَخِيهِ، إِبْرَاهِيمَ بْنِ عَبْدِ اللَّهِ عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{1491}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{The above mentioned tradition has also been transmitted in a similar manner by Ibn 'Abbas from the Messenger of Allah (ﷺ)}}
\hadithdefcmd{abudawud}{1492}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا ابْنُ لَهِيعَةَ، عَنْ حَفْصِ بْنِ هَاشِمِ بْنِ عُتْبَةَ بْنِ أَبِي وَقَّاصٍ، عَنِ السَّائِبِ بْنِ يَزِيدَ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا دَعَا فَرَفَعَ يَدَيْهِ مَسَحَ وَجْهَهُ بِيَدَيْهِ ‏.‏\hadithno{1492}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Yazid ibn Sa'id al-Kindi: When the Prophet (ﷺ) made supplication (to Allah) he would raise his hands and wipe his face with his hands}}
\hadithdefcmd{abudawud}{1493}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ مَالِكِ بْنِ مِغْوَلٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بُرَيْدَةَ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سَمِعَ رَجُلاً يَقُولُ اللَّهُمَّ إِنِّي أَسْأَلُكَ أَنِّي أَشْهَدُ أَنَّكَ أَنْتَ اللَّهُ لاَ إِلَهَ إِلاَّ أَنْتَ الأَحَدُ الصَّمَدُ الَّذِي لَمْ يَلِدْ وَلَمْ يُولَدْ وَلَمْ يَكُنْ لَهُ كُفُوًا أَحَدٌ ‏.‏ فَقَالَ ‏ "‏ لَقَدْ سَأَلْتَ اللَّهَ بِالاِسْمِ الَّذِي إِذَا سُئِلَ بِهِ أَعْطَى وَإِذَا دُعِيَ بِهِ أَجَابَ ‏"‏ ‏.‏\hadithno{1493}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Buraydah ibn al-Hasib: The Messenger of Allah (ﷺ) heard a man saying: O Allah, I ask Thee, I bear witness that there is no god but Thou, the One, He to Whom men repair, Who has not begotten, and has not been begotten, and to Whom no one is equal, and he said: You have supplicated Allah using His Greatest Name, when asked with this name He gives, and when supplicated by this name he answers}}
\hadithdefcmd{abudawud}{1494}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ خَالِدٍ الرَّقِّيُّ، حَدَّثَنَا زَيْدُ بْنُ حُبَابٍ، حَدَّثَنَا مَالِكُ بْنُ مِغْوَلٍ، بِهَذَا الْحَدِيثِ قَالَ فِيهِ ‏ "‏ لَقَدْ سَأَلْتَ اللَّهَ عَزَّ وَجَلَّ بِاسْمِهِ الأَعْظَمِ ‏"‏ ‏.‏\hadithno{1494}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The aforesaid tradition has been transmitted through a different chain of narrators by Malik b. Mighwal. This verso adds:"He has asked Allah using His Greatest Name}}
\hadithdefcmd{abudawud}{1495}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ عُبَيْدِ اللَّهِ الْحَلَبِيُّ، حَدَّثَنَا خَلَفُ بْنُ خَلِيفَةَ، عَنْ حَفْصٍ، - يَعْنِي ابْنَ أَخِي أَنَسٍ - عَنْ أَنَسٍ، أَنَّهُ كَانَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم جَالِسًا وَرَجُلٌ يُصَلِّي ثُمَّ دَعَا اللَّهُمَّ إِنِّي أَسْأَلُكَ بِأَنَّ لَكَ الْحَمْدَ لاَ إِلَهَ إِلاَّ أَنْتَ الْمَنَّانُ بَدِيعُ السَّمَوَاتِ وَالأَرْضِ يَا ذَا الْجَلاَلِ وَالإِكْرَامِ يَا حَىُّ يَا قَيُّومُ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لَقَدْ دَعَا اللَّهَ بِاسْمِهِ الْعَظِيمِ الَّذِي إِذَا دُعِيَ بِهِ أَجَابَ وَإِذَا سُئِلَ بِهِ أَعْطَى ‏"‏ ‏.‏\hadithno{1495}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Anas ibn Malik: I was sitting with the Messenger of Allah (ﷺ) and a man was offering prayer. He then made supplication: O Allah, I ask Thee by virtue of the fact that praise is due to Thee, there is no deity but Thou, Who showest favour and beneficence, the Originator of the Heavens and the earth, O Lord of Majesty and Splendour, O Living One, O Eternal One. The Prophet (ﷺ) then said: He has supplicated Allah using His Greatest Name, when supplicated by this name, He answers, and when asked by this name He gives}}
\hadithdefcmd{abudawud}{1496}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ أَبِي زِيَادٍ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ أَسْمَاءَ بِنْتِ يَزِيدَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ اسْمُ اللَّهِ الأَعْظَمُ فِي هَاتَيْنِ الآيَتَيْنِ ‏\{‏ وَإِلَهُكُمْ إِلَهٌ وَاحِدٌ لاَ إِلَهَ إِلاَّ هُوَ الرَّحْمَنُ الرَّحِيمُ ‏\}‏ وَفَاتِحَةُ سُورَةِ آلِ عِمْرَانَ ‏\{‏ الم * اللَّهُ لاَ إِلَهَ إِلاَّ هُوَ الْحَىُّ الْقَيُّومُ ‏\}‏ ‏.‏\hadithno{1496}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Asma daughter of Yazid reported the Prophet (ﷺ) as saying:"Allah's Greatest Names is in these two verses: "And your Ilaah (God) is One Ilaah (God), none has the right to be worshipped but He, the Ever-Merciful, the Mercy-Giving' and the beginning of Surah Al 'Imran, "A.L.M Allah, there is no deity but He, the Living, the Eternal}}
\hadithdefcmd{abudawud}{1497}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنِ الأَعْمَشِ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ عَطَاءٍ، عَنْ عَائِشَةَ، قَالَتْ سُرِقَتْ مِلْحَفَةٌ لَهَا فَجَعَلَتْ تَدْعُو عَلَى مَنْ سَرَقَهَا فَجَعَلَ النَّبِيُّ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ تُسَبِّخِي عَنْهُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ لاَ تُسَبِّخِي أَىْ لاَ تُخَفِّفِي عَنْهُ ‏.‏\hadithno{1497}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: Ata' said: The quilt of Aisha was stolen. She began to curse the person who had stolen it. The Prophet (ﷺ) began to tell her: Do not lighten him. Abu Dawud said: The meaning of the Arabic words la tasbikhi 'anhu means "do not lessen him or lighten him}}
\hadithdefcmd{abudawud}{1498}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَاصِمِ بْنِ عُبَيْدِ اللَّهِ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، عَنْ عُمَرَ، - رضى الله عنه - قَالَ اسْتَأْذَنْتُ النَّبِيَّ صلى الله عليه وسلم فِي الْعُمْرَةِ فَأَذِنَ لِي وَقَالَ ‏"‏ لاَ تَنْسَنَا يَا أُخَىَّ مِنْ دُعَائِكَ ‏"‏ ‏.‏ فَقَالَ كَلِمَةً مَا يَسُرُّنِي أَنَّ لِي بِهَا الدُّنْيَا قَالَ شُعْبَةُ ثُمَّ لَقِيتُ عَاصِمًا بَعْدُ بِالْمَدِينَةِ فَحَدَّثَنِيهِ وَقَالَ ‏"‏ أَشْرِكْنَا يَا أُخَىَّ فِي دُعَائِكَ ‏"‏ ‏.‏\hadithno{1498}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Umar ibn al-Khattab: I sought permission of the Prophet (ﷺ) to perform umrah. He gave me permission and said: My younger brother, do not forget me in your supplication. He (Umar) said: He told me a word that pleased me so much so that I would not have been pleased if I were given the whole world. The narrator Shu'bah said: I then met Asim at Medina. He narrated to me this tradition and reported the wordings: "My younger brother, share me in your supplication}}
\hadithdefcmd{abudawud}{1499}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي صَالِحٍ، عَنْ سَعْدِ بْنِ أَبِي وَقَّاصٍ، قَالَ مَرَّ عَلَىَّ النَّبِيُّ صلى الله عليه وسلم وَأَنَا أَدْعُو بِأُصْبُعَىَّ فَقَالَ ‏ "‏ أَحِّدْ أَحِّدْ ‏"‏ ‏.‏ وَأَشَارَ بِالسَّبَّابَةِ ‏.‏\hadithno{1499}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Sa'd ibn AbuWaqqas: The Prophet (ﷺ) passed by me while I was supplicating by pointing with two fingers of mine. He said: Point with one finger; point with one finger. He then himself pointed with the forefinger}}
\hadithdefcmd{abudawud}{1500}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، أَنَّ سَعِيدَ بْنَ أَبِي هِلاَلٍ، حَدَّثَهُ عَنْ خُزَيْمَةَ، عَنْ عَائِشَةَ بِنْتِ سَعْدِ بْنِ أَبِي وَقَّاصٍ، عَنْ أَبِيهَا، أَنَّهُ دَخَلَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَلَى امْرَأَةٍ وَبَيْنَ يَدَيْهَا نَوًى أَوْ حَصًى تُسَبِّحُ بِهِ فَقَالَ ‏"‏ أُخْبِرُكِ بِمَا هُوَ أَيْسَرُ عَلَيْكِ مِنْ هَذَا أَوْ أَفْضَلُ ‏"‏ ‏.‏ فَقَالَ ‏"‏ سُبْحَانَ اللَّهِ عَدَدَ مَا خَلَقَ فِي السَّمَاءِ وَسُبْحَانَ اللَّهِ عَدَدَ مَا خَلَقَ فِي الأَرْضِ وَسُبْحَانَ اللَّهِ عَدَدَ مَا خَلَقَ بَيْنَ ذَلِكَ وَسُبْحَانَ اللَّهِ عَدَدَ مَا هُوَ خَالِقٌ وَاللَّهُ أَكْبَرُ مِثْلُ ذَلِكَ وَالْحَمْدُ لِلَّهِ مِثْلُ ذَلِكَ ‏.‏ وَلاَ إِلَهَ إِلاَّ اللَّهُ مِثْلُ ذَلِكَ ‏.‏ وَلاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ مِثْلُ ذَلِكَ ‏"‏ ‏.‏\hadithno{1500}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Sa'd ibn AbuWaqqas: Once Sa'd, with the Messenger of Allah (ﷺ), visited a woman in front of whom were some date-stones or pebbles which she was using as a rosary to glorify Allah. He (the Prophet) said: I tell you something which would be easier (or more excellent) for you than that. He said (it consisted of saying): "Glory be to Allah" as many times as the number of that which He has created in Heaven; "Glory be to Allah" as many times as the number of that which He has created on Earth; "Glory be to Allah" as many times as the number of that which He has created between them; "Glory be to Allah" as many times as the number of that which He is creating; "Allah is most great" a similar number of times; "Praise (be to Allah)" a similar number of times; and "There is no god but Allah" a similar number of times; "There is no might and no power except in Allah" a similar number of times}}
\hadithdefcmd{abudawud}{1501}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دَاوُدَ، عَنْ هَانِئِ بْنِ عُثْمَانَ، عَنْ حُمَيْضَةَ بِنْتِ يَاسِرٍ، عَنْ يُسَيْرَةَ، أَخْبَرَتْهَا أَنَّ النَّبِيَّ صلى الله عليه وسلم أَمَرَهُنَّ أَنْ يُرَاعِينَ بِالتَّكْبِيرِ وَالتَّقْدِيسِ وَالتَّهْلِيلِ وَأَنْ يَعْقِدْنَ بِالأَنَامِلِ فَإِنَّهُنَّ مَسْئُولاَتٌ مُسْتَنْطَقَاتٌ ‏.‏\hadithno{1501}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Yusayrah, mother of Yasir: The Prophet (ﷺ) commanded them (the women emigrants) to be regular (in remembering Allah by saying): "Allah is most great"; "Glory be to the King, the Holy"; "there is no god but Allah"; and that they should count them on fingers, for they (the fingers) will be questioned and asked to speak}}
\hadithdefcmd{abudawud}{1502}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ بْنِ مَيْسَرَةَ، وَمُحَمَّدُ بْنُ قُدَامَةَ، - فِي آخَرِينَ - قَالُوا حَدَّثَنَا عَثَّامٌ، عَنِ الأَعْمَشِ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم - يَعْقِدُ التَّسْبِيحَ قَالَ ابْنُ قُدَامَةَ - بِيَمِينِهِ ‏.‏\hadithno{1502}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: I saw the Messenger of Allah (ﷺ) counting the glorification of Allah on fingers. Ibn Qudamah said (in his version: "With his right hands)}}
\hadithdefcmd{abudawud}{1503}{حَدَّثَنَا دَاوُدُ بْنُ أُمَيَّةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، مَوْلَى أَبِي طَلْحَةَ عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ عِنْدِ جُوَيْرِيَةَ - وَكَانَ اسْمُهَا بَرَّةَ فَحَوَّلَ اسْمَهَا - فَخَرَجَ وَهِيَ فِي مُصَلاَّهَا وَرَجَعَ وَهِيَ فِي مُصَلاَّهَا فَقَالَ ‏"‏ لَمْ تَزَالِي فِي مُصَلاَّكِ هَذَا ‏"‏ ‏.‏ قَالَتْ نَعَمْ ‏.‏ قَالَ ‏"‏ قَدْ قُلْتُ بَعْدَكِ أَرْبَعَ كَلِمَاتٍ ثَلاَثَ مَرَّاتٍ لَوْ وُزِنَتْ بِمَا قُلْتِ لَوَزَنَتْهُنَّ سُبْحَانَ اللَّهِ وَبِحَمْدِهِ عَدَدَ خَلْقِهِ وَرِضَا نَفْسِهِ وَزِنَةَ عَرْشِهِ وَمِدَادَ كَلِمَاتِهِ ‏"‏ ‏.‏\hadithno{1503}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (2726)}\hadithtrans{Narrated Abdullah Ibn Abbas: The Messenger of Allah (ﷺ) went out from Juwayriyyah (wife of the Prophet). Earlier her name was Barrah, and he changed it. When he went out she was in her place of worship, and when he returned she was in her place of worship. He asked: Have you been in your place of worship continuously? She said: Yes. He then said: Since leaving you I have said three times four phrases which, if weighed against all that you have said (during this period), would prove to be heavier: "Glory be to Allah, and I begin with praise of Him to the number of His creatures, in accordance with His good pleasure, to the weight of His throne and to the ink (extent) of His words}}
\hadithdefcmd{abudawud}{1504}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنِي حَسَّانُ بْنُ عَطِيَّةَ، قَالَ حَدَّثَنِي مُحَمَّدُ بْنُ أَبِي عَائِشَةَ، قَالَ حَدَّثَنِي أَبُو هُرَيْرَةَ، قَالَ قَالَ أَبُو ذَرٍّ يَا رَسُولَ اللَّهِ ذَهَبَ أَصْحَابُ الدُّثُورِ بِالأُجُورِ يُصَلُّونَ كَمَا نُصَلِّي وَيَصُومُونَ كَمَا نَصُومُ وَلَهُمْ فُضُولُ أَمْوَالٍ يَتَصَدَّقُونَ بِهَا وَلَيْسَ لَنَا مَالٌ نَتَصَدَّقُ بِهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا أَبَا ذَرٍّ أَلاَ أُعَلِّمُكَ كَلِمَاتٍ تُدْرِكُ بِهِنَّ مَنْ سَبَقَكَ وَلاَ يَلْحَقُكَ مَنْ خَلْفَكَ إِلاَّ مَنْ أَخَذَ بِمِثْلِ عَمَلِكَ ‏"‏ ‏.‏ قَالَ بَلَى يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ تُكَبِّرُ اللَّهَ عَزَّ وَجَلَّ دُبُرَ كُلِّ صَلاَةٍ ثَلاَثًا وَثَلاَثِينَ وَتَحْمَدُهُ ثَلاَثًا وَثَلاَثِينَ وَتُسَبِّحُهُ ثَلاَثًا وَثَلاَثِينَ وَتَخْتِمُهَا بِلاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ وَهُوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ غُفِرَتْ لَهُ ذُنُوبُهُ وَلَوْ كَانَتْ مِثْلَ زَبَدِ الْبَحْرِ ‏"‏ ‏.‏\hadithno{1504}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuHurayrah: AbuDharr said: Prophet of Allah. The wealthy people have all the rewards; they pray as we pray; they fast as we fast; and they have surplus wealth which they give in charity; but we have no wealth which we may give in charity. The Messenger of Allah (ﷺ) said: AbuDharr, should I not teach you phrases by which you acquire the rank of those who excel you? No one can acquire your rank except one who acts like you. He said: Why not, Messenger of Allah? He said: Exalt Allah (say: Allah is Most Great) after each prayer thirty-three times; and praise Him (say: Praise be to Allah) thirty-three times; and glorify Him (say: Glory be to Allah) thirty-three times, and end it by saying, "There is no god but Allah alone, there is no partner, to Him belongs the Kingdom, to Him praise is due and He has power over everything". His sins will be forgiven, even if they are like the foam of the sea}}
\hadithdefcmd{abudawud}{1505}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنِ الْمُسَيَّبِ بْنِ رَافِعٍ، عَنْ وَرَّادٍ، مَوْلَى الْمُغِيرَةِ بْنِ شُعْبَةَ عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، كَتَبَ مُعَاوِيَةُ إِلَى الْمُغِيرَةِ بْنِ شُعْبَةَ أَىُّ شَىْءٍ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ إِذَا سَلَّمَ مِنَ الصَّلاَةِ فَأَمْلاَهَا الْمُغِيرَةُ عَلَيْهِ وَكَتَبَ إِلَى مُعَاوِيَةَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ وَهُوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ اللَّهُمَّ لاَ مَانِعَ لِمَا أَعْطَيْتَ وَلاَ مُعْطِيَ لِمَا مَنَعْتَ وَلاَ يَنْفَعُ ذَا الْجَدِّ مِنْكَ الْجَدُّ ‏"‏ ‏.‏\hadithno{1505}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (844) Sahih Muslim (593)}\hadithtrans{Al-Mughirah b. Shu'bah reported:"Mu'awiyah wrote to al-Mughirah b. Shu'bah: 'What would the the Messenger of Allah (ﷺ) recite when he gave Taslim (salutation) in the prayer ?' Al-Mughirah dictated and wrote to Mu'awiyah: 'The Messenger of Allah (ﷺ) used to say (at the end of the prayer after taslim): 'There is no God but Allah, Alone, Who has no partner, to Him belongs the dominion, to Him praise is due, and He is Omnipotent. O Allah no one cane withhold what You give and give what You withhold, and none benefits the fortunate person, for from You is the fortune}}
\hadithdefcmd{abudawud}{1506}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، قَالَ حَدَّثَنَا ابْنُ عُلَيَّةَ، عَنِ الْحَجَّاجِ بْنِ أَبِي عُثْمَانَ، عَنْ أَبِي الزُّبَيْرِ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ الزُّبَيْرِ، عَلَى الْمِنْبَرِ يَقُولُ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا انْصَرَفَ مِنَ الصَّلاَةِ يَقُولُ ‏ "‏ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ وَهُوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ لاَ إِلَهَ إِلاَّ اللَّهُ مُخْلِصِينَ لَهُ الدِّينَ وَلَوْ كَرِهَ الْكَافِرُونَ أَهْلُ النِّعْمَةِ وَالْفَضْلِ وَالثَّنَاءِ الْحَسَنِ لاَ إِلَهَ إِلاَّ اللَّهُ مُخْلِصِينَ لَهُ الدِّينَ وَلَوْ كَرِهَ الْكَافِرُونَ ‏"‏ ‏.‏\hadithno{1506}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (594)}\hadithtrans{Abu Zubair said:"I heard 'Abd Allah b. al-Zubair saying on the pulpit: When the Prophet (ﷺ) finished the prayer, he used to say (at the end of the prayer): 'There is no God but Allah, Alone, Who has no partner, to Him belongs the Kingdom, to Him praise is due, and He is Omnipotent. There is no God but Allah to Whom we are sincere in devotion, even though the infidels should disapprove. To Him belongs wealth, to Him belongs grace and to Him is worthy accorded. There is no got but Allah to Whom we are sincere in devotion, even though infidels should disapprove}}
\hadithdefcmd{abudawud}{1507}{حَدَّثَنَا مُحَمَّدُ بْنُ سُلَيْمَانَ الأَنْبَارِيُّ، حَدَّثَنَا عَبْدَةُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِي الزُّبَيْرِ، قَالَ كَانَ عَبْدُ اللَّهِ بْنُ الزُّبَيْرِ يُهَلِّلُ فِي دُبُرِ كُلِّ صَلاَةٍ فَذَكَرَ نَحْوَ هَذَا الدُّعَاءِ زَادَ فِيهِ ‏ "‏ وَلاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ لاَ إِلَهَ إِلاَّ اللَّهُ لاَ نَعْبُدُ إِلاَّ إِيَّاهُ لَهُ النِّعْمَةُ ‏"‏ ‏.‏ وَسَاقَ بَقِيَّةَ الْحَدِيثِ ‏.‏\hadithno{1507}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu al-Zubair said:'Abd Allah b. al-Zubair used to recite this supplication after each (prescribed) prayer. He then narrated a similar supplication and added to it: "There is no might and no power except in Allah; there is no god but Allah Whom alone we worship. To Him belongs wealth." The narrator then transmitted the rest of tradition}}
\hadithdefcmd{abudawud}{1508}{حَدَّثَنَا مُسَدَّدٌ، وَسُلَيْمَانُ بْنُ دَاوُدَ الْعَتَكِيُّ، - وَهَذَا حَدِيثُ مُسَدَّدٍ - قَالاَ حَدَّثَنَا الْمُعْتَمِرُ، قَالَ سَمِعْتُ دَاوُدَ الطُّفَاوِيَّ، قَالَ حَدَّثَنِي أَبُو مُسْلِمٍ الْبَجَلِيُّ، عَنْ زَيْدِ بْنِ أَرْقَمَ، قَالَ سَمِعْتُ نَبِيَّ اللَّهِ صلى الله عليه وسلم يَقُولُ وَقَالَ سُلَيْمَانُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ فِي دُبُرِ صَلاَتِهِ ‏"‏ اللَّهُمَّ رَبَّنَا وَرَبَّ كُلِّ شَىْءٍ أَنَا شَهِيدٌ أَنَّكَ أَنْتَ الرَّبُّ وَحْدَكَ لاَ شَرِيكَ لَكَ اللَّهُمَّ رَبَّنَا وَرَبَّ كُلِّ شَىْءٍ أَنَا شَهِيدٌ أَنَّ مُحَمَّدًا عَبْدُكَ وَرَسُولُكَ اللَّهُمَّ رَبَّنَا وَرَبَّ كُلِّ شَىْءٍ أَنَا شَهِيدٌ أَنَّ الْعِبَادَ كُلَّهُمْ إِخْوَةٌ اللَّهُمَّ رَبَّنَا وَرَبَّ كُلِّ شَىْءٍ اجْعَلْنِي مُخْلِصًا لَكَ وَأَهْلِي فِي كُلِّ سَاعَةٍ فِي الدُّنْيَا وَالآخِرَةِ يَا ذَا الْجَلاَلِ وَالإِكْرَامِ اسْمَعْ وَاسْتَجِبِ اللَّهُ أَكْبَرُ الأَكْبَرُ اللَّهُمَّ نُورَ السَّمَوَاتِ وَالأَرْضِ ‏"‏ ‏.‏ قَالَ سُلَيْمَانُ بْنُ دَاوُدَ ‏"‏ رَبَّ السَّمَوَاتِ وَالأَرْضِ ‏"‏ ‏.‏ ‏"‏ اللَّهُ أَكْبَرُ الأَكْبَرُ حَسْبِيَ اللَّهُ وَنِعْمَ الْوَكِيلُ اللَّهُ أَكْبَرُ الأَكْبَرُ ‏"‏ ‏.‏\hadithno{1508}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Zayd ibn Arqam: I heard the Messenger of Allah (ﷺ) saying (the version of Sulayman has: The Messenger of Allah (ﷺ) used to say) after his prayer:- "O Allah, our Lord and Lord of everything, I bear witness that Thou art the Lord alone Who hast no partner; O Allah, Our Lord and Lord of everything, I bear witness that Muhammad is Thy servant and Thy apostle ; O Allah, our Lord and Lord of everything, I bear witness that all the servants are brethren; O Allah, our Lord and Lord of everything make me sincere to Thee, and my family too at every moment, in this world and in the world hereafter, O Possessor of glory and honour, listen to me and answer. Allah is incomparably great. O Allah, Light of the heavens and of the earth". The narrator Sulaiman b. Dawud said: "Lord of the heavens and of the earth, Allah is incomparably great. Allah is sufficient for me; and the excellent guardian is He; Allah is incomparably great}}
\hadithdefcmd{abudawud}{1509}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، قَالَ حَدَّثَنَا أَبِي، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي سَلَمَةَ، عَنْ عَمِّهِ الْمَاجِشُونَ بْنِ أَبِي سَلَمَةَ، عَنْ عَبْدِ الرَّحْمَنِ الأَعْرَجِ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي رَافِعٍ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا سَلَّمَ مِنَ الصَّلاَةِ قَالَ ‏ "‏ اللَّهُمَّ اغْفِرْ لِي مَا قَدَّمْتُ وَمَا أَخَّرْتُ وَمَا أَسْرَرْتُ وَمَا أَعْلَنْتُ وَمَا أَسْرَفْتُ وَمَا أَنْتَ أَعْلَمُ بِهِ مِنِّي أَنْتَ الْمُقَدِّمُ وَأَنْتَ الْمُؤَخِّرُ لاَ إِلَهَ إِلاَّ أَنْتَ ‏"‏ ‏.‏\hadithno{1509}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ali b. Abi Talib said:When the Prophet (ﷺ) uttered salutation at the end of the prayer, he used to say: "O Allah, forgive me my former and latter sins, what I have kept secret and what I have done openly, and what I have done extravagance; and what You know better than I do. You are the Advancer, the Delayer, there is no god but You}}
\hadithdefcmd{abudawud}{1510}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، عَنْ طُلَيْقِ بْنِ قَيْسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَدْعُو ‏ "‏ رَبِّ أَعِنِّي وَلاَ تُعِنْ عَلَىَّ وَانْصُرْنِي وَلاَ تَنْصُرْ عَلَىَّ وَامْكُرْ لِي وَلاَ تَمْكُرْ عَلَىَّ وَاهْدِنِي وَيَسِّرْ هُدَاىَ إِلَىَّ وَانْصُرْنِي عَلَى مَنْ بَغَى عَلَىَّ اللَّهُمَّ اجْعَلْنِي لَكَ شَاكِرًا لَكَ ذَاكِرًا لَكَ رَاهِبًا لَكَ مِطْوَاعًا إِلَيْكَ مُخْبِتًا أَوْ مُنِيبًا رَبِّ تَقَبَّلْ تَوْبَتِي وَاغْسِلْ حَوْبَتِي وَأَجِبْ دَعْوَتِي وَثَبِّتْ حُجَّتِي وَاهْدِ قَلْبِي وَسَدِّدْ لِسَانِي وَاسْلُلْ سَخِيمَةَ قَلْبِي ‏"‏ ‏.‏\hadithno{1510}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) used to supplicate Allah: "My Lord, help me and do not give help against me; grant me victory, and do not grant victory over me; plan on my behalf and do not plan against me; guide me, and made my right guidance easy for me; grant me victory over those who act wrongfully towards me; O Allah, make me grateful to Thee, mindful of Thee, full of fear towards Thee, devoted to Thy obedience, humble before Thee, or penitent. My Lord, accept my repentance, wash away my sin, answer my supplication, clearly establish my evidence, guide my heart, make true my tongue and draw out malice in my breast}}
\hadithdefcmd{abudawud}{1511}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، قَالَ سَمِعْتُ عَمْرَو بْنَ مُرَّةَ، بِإِسْنَادِهِ وَمَعْنَاهُ قَالَ ‏"‏ وَيَسِّرِ الْهُدَى إِلَىَّ ‏"‏ ‏.‏ وَلَمْ يَقُلْ ‏"‏ هُدَاىَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ سَمِعَ سُفْيَانُ مِنْ عَمْرِو بْنِ مُرَّةَ قَالُوا ثَمَانِيَةَ عَشَرَ حَدِيثًا ‏.‏\hadithno{1511}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The aforesaid tradition has also been transmitted by 'Amr b. Murrah through a different chain of narrators to the same effect. This version adds:"And make right guidance easy for me." The narrator did not say: "my right guidance". Abu Dawud said: Sufyan heard eighteen traditions from 'Amr b. Murrah}}
\hadithdefcmd{abudawud}{1512}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا شُعْبَةُ، عَنْ عَاصِمٍ الأَحْوَلِ، وَخَالِدٍ الْحَذَّاءِ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، عَنْ عَائِشَةَ، رضى الله عنها أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا سَلَّمَ قَالَ ‏ "‏ اللَّهُمَّ أَنْتَ السَّلاَمُ وَمِنْكَ السَّلاَمُ تَبَارَكْتَ يَا ذَا الْجَلاَلِ وَالإِكْرَامِ ‏"‏ ‏.‏\hadithno{1512}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (592)}\hadithtrans{Aishah said:When the Prophet (ﷺ) uttered taslim, he used to say: "O Allah, You are As-Salam, and from you is As-Salam. You are blessed, O One of Magnificence and Generosity}}
\hadithdefcmd{abudawud}{1513}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا عِيسَى، عَنِ الأَوْزَاعِيِّ، عَنْ أَبِي عَمَّارٍ، عَنْ أَبِي أَسْمَاءَ، عَنْ ثَوْبَانَ، مَوْلَى رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا أَرَادَ أَنْ يَنْصَرِفَ مِنْ صَلاَتِهِ اسْتَغْفَرَ ثَلاَثَ مَرَّاتٍ ثُمَّ قَالَ ‏ "‏ اللَّهُمَّ ‏"‏ ‏.‏ فَذَكَرَ مَعْنَى حَدِيثِ عَائِشَةَ رضى الله عنها ‏.‏\hadithno{1513}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (591)}\hadithtrans{Thawban, the client of Messenger of Allah (ﷺ) said:When the Prophet (ﷺ) finished the prayer, he asked forgiveness three times and said: "O Allah ....." The narrator then narrated the tradition like that of 'Aishah}}
\hadithdefcmd{abudawud}{1514}{حَدَّثَنَا النُّفَيْلِيُّ، حَدَّثَنَا مَخْلَدُ بْنُ يَزِيدَ، حَدَّثَنَا عُثْمَانُ بْنُ وَاقِدٍ الْعُمَرِيُّ، عَنْ أَبِي نُصَيْرَةَ، عَنْ مَوْلًى، لأَبِي بَكْرٍ الصِّدِّيقِ عَنْ أَبِي بَكْرٍ الصِّدِّيقِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا أَصَرَّ مَنِ اسْتَغْفَرَ وَإِنْ عَادَ فِي الْيَوْمِ سَبْعِينَ مَرَّةً ‏"‏ ‏.‏\hadithno{1514}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated AbuBakr as-Siddiq: The Prophet (ﷺ) said: He who asks pardon is not a confirmed sinner, even if he returns to his sin seventy times a day}}
\hadithdefcmd{abudawud}{1515}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، وَمُسَدَّدٌ، قَالاَ حَدَّثَنَا حَمَّادٌ، عَنْ ثَابِتٍ، عَنْ أَبِي بُرْدَةَ، عَنِ الأَغَرِّ الْمُزَنِيِّ، - قَالَ مُسَدَّدٌ فِي حَدِيثِهِ وَكَانَتْ لَهُ صُحْبَةٌ - قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّهُ لَيُغَانُ عَلَى قَلْبِي وَإِنِّي لأَسْتَغْفِرُ اللَّهَ فِي كُلِّ يَوْمٍ مِائَةَ مَرَّةٍ ‏"‏ ‏.‏\hadithno{1515}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2702)}\hadithtrans{Al-Agharr al-Muzani said (Musaddad in his version of this tradition said that he was a Companion of the Prophet):The Messenger of Allah (ﷺ) said: My heart is invaded by unmindfulness, and I ask Allah's pardon a hundred times in the day}}
\hadithdefcmd{abudawud}{1516}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ مَالِكِ بْنِ مِغْوَلٍ، عَنْ مُحَمَّدِ بْنِ سُوقَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ إِنْ كُنَّا لَنَعُدُّ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فِي الْمَجْلِسِ الْوَاحِدِ مِائَةَ مَرَّةٍ ‏ "‏ رَبِّ اغْفِرْ لِي وَتُبْ عَلَىَّ إِنَّكَ أَنْتَ التَّوَّابُ الرَّحِيمُ ‏"‏ ‏.‏\hadithno{1516}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abdullah ibn Umar: We counted that the Messenger of Allah (ﷺ) would say a hundred times during a meeting: "My Lord, forgive me and pardon me; Thou art the Pardoning and forgiving One}}
\hadithdefcmd{abudawud}{1517}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَفْصُ بْنُ عُمَرَ الشَّنِّيُّ، حَدَّثَنِي أَبِي عُمَرُ بْنُ مُرَّةَ، قَالَ سَمِعْتُ بِلاَلَ بْنَ يَسَارِ بْنِ زَيْدٍ، مَوْلَى النَّبِيِّ صلى الله عليه وسلم قَالَ سَمِعْتُ أَبِي يُحَدِّثُنِيهِ عَنْ جَدِّي أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ قَالَ أَسْتَغْفِرُ اللَّهَ الَّذِي لاَ إِلَهَ إِلاَّ هُوَ الْحَىُّ الْقَيُّومُ وَأَتُوبُ إِلَيْهِ غُفِرَ لَهُ وَإِنْ كَانَ فَرَّ مِنَ الزَّحْفِ ‏"‏ ‏.‏\hadithno{1517}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Zayd, the client of the Prophet: The Prophet (ﷺ) said: If anyone says: "I ask pardon of Allah than Whom there is no deity, the Living, the eternal, and I turn to Him in repentance," he will be pardoned, even if he has fled in time of battle}}
\hadithdefcmd{abudawud}{1518}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الْحَكَمُ بْنُ مُصْعَبٍ، حَدَّثَنَا مُحَمَّدُ بْنُ عَلِيِّ بْنِ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، عَنْ أَبِيهِ، أَنَّهُ حَدَّثَهُ عَنِ ابْنِ عَبَّاسٍ، أَنَّهُ حَدَّثَهُ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ لَزِمَ الاِسْتِغْفَارَ جَعَلَ اللَّهُ لَهُ مِنْ كُلِّ ضِيقٍ مَخْرَجًا وَمِنْ كُلِّ هَمٍّ فَرَجًا وَرَزَقَهُ مِنْ حَيْثُ لاَ يَحْتَسِبُ ‏"‏ ‏.‏\hadithno{1518}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) said: If anyone continually asks pardon, Allah will appoint for him a way out of every distress, and a relief from every anxiety, and will provide for him from where he did not reckon}}
\hadithdefcmd{abudawud}{1519}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَارِثِ، ح وَحَدَّثَنَا زِيَادُ بْنُ أَيُّوبَ، حَدَّثَنَا إِسْمَاعِيلُ، - الْمَعْنَى - عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، قَالَ سَأَلَ قَتَادَةُ أَنَسًا أَىُّ دَعْوَةٍ كَانَ يَدْعُو بِهَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَكْثَرَ قَالَ كَانَ أَكْثَرُ دَعْوَةٍ يَدْعُو بِهَا ‏ "‏ اللَّهُمَّ رَبَّنَا آتِنَا فِي الدُّنْيَا حَسَنَةً وَفِي الآخِرَةِ حَسَنَةً وَقِنَا عَذَابَ النَّارِ ‏"‏ ‏.‏ وَزَادَ زِيَادٌ وَكَانَ أَنَسٌ إِذَا أَرَادَ أَنْ يَدْعُوَ بِدَعْوَةٍ دَعَا بِهَا وَإِذَا أَرَادَ أَنْ يَدْعُوَ بِدُعَاءٍ دَعَا بِهَا فِيهَا ‏.‏\hadithno{1519}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6389) Sahih Muslim (2690)}\hadithtrans{Qatadah asked Anas:Which Supplication would the Prophet (ﷺ) often make ? He replied: The supplication he would usually recite was: "O Allah, give us in this world what is good and in the next what is good, and protect us from the punishment of Hell-fire". The version of Ziyad adds: When Anas wished to supplicate, he uttered this supplication. When he uttered some other supplication, he combined it with this supplication}}
\hadithdefcmd{abudawud}{1520}{حَدَّثَنَا يَزِيدُ بْنُ خَالِدٍ الرَّمْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ شُرَيْحٍ، عَنْ أَبِي أُمَامَةَ بْنِ سَهْلِ بْنِ حُنَيْفٍ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ سَأَلَ اللَّهَ الشَّهَادَةَ صَادِقًا بَلَّغَهُ اللَّهُ مَنَازِلَ الشُّهَدَاءِ وَإِنْ مَاتَ عَلَى فِرَاشِهِ ‏"‏ ‏.‏\hadithno{1520}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1909)}\hadithtrans{Sahl b. Hunaif reported:The Messenger of Allah (ﷺ) said: If anyone asks Allah for martyrdom sincerely, Allah will make him reach the ranks of martyrs even if he died on his bed}}
\hadithdefcmd{abudawud}{1521}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ عُثْمَانَ بْنِ الْمُغِيرَةِ الثَّقَفِيِّ، عَنْ عَلِيِّ بْنِ رَبِيعَةَ الأَسَدِيِّ، عَنْ أَسْمَاءَ بْنِ الْحَكَمِ الْفَزَارِيِّ، قَالَ سَمِعْتُ عَلِيًّا، - رَضِيَ اللَّهُ عَنْهُ - يَقُولُ كُنْتُ رَجُلاً إِذَا سَمِعْتُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم حَدِيثًا نَفَعَنِي اللَّهُ مِنْهُ بِمَا شَاءَ أَنْ يَنْفَعَنِي وَإِذَا حَدَّثَنِي أَحَدٌ مِنْ أَصْحَابِهِ اسْتَحْلَفْتُهُ فَإِذَا حَلَفَ لِي صَدَّقْتُهُ قَالَ وَحَدَّثَنِي أَبُو بَكْرٍ وَصَدَقَ أَبُو بَكْرٍ - رضى الله عنه - أَنَّهُ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ مَا مِنْ عَبْدٍ يُذْنِبُ ذَنْبًا فَيُحْسِنُ الطُّهُورَ ثُمَّ يَقُومُ فَيُصَلِّي رَكْعَتَيْنِ ثُمَّ يَسْتَغْفِرُ اللَّهَ إِلاَّ غَفَرَ اللَّهُ لَهُ ‏"‏ ‏.‏ ثُمَّ قَرَأَ هَذِهِ الآيَةَ ‏\{‏ وَالَّذِينَ إِذَا فَعَلُوا فَاحِشَةً أَوْ ظَلَمُوا أَنْفُسَهُمْ ذَكَرُوا اللَّهَ ‏\}‏ إِلَى آخِرِ الآيَةِ ‏.‏\hadithno{1521}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuBakr as-Siddiq: Asma' bint al-Hakam said: I heard Ali say: I was a man; when I heard a tradition from the Messenger of Allah (ﷺ), Allah benefited me with it as much as He willed. But when some one of his companions narrated a tradition to me I adjured him. When he took an oath, I testified him. AbuBakr narrated to me a tradition, and AbuBakr narrated truthfully. He said: I heard the apostle of Allah (ﷺ) saying: When a servant (of Allah) commits a sin, and he performs ablution well, and then stands and prays two rak'ahs, and asks pardon of Allah, Allah pardons him. He then recited this verse: "And those who, when they commit indecency or wrong their souls, remember Allah" (Al-Qur'an 3:)}}
\hadithdefcmd{abudawud}{1522}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ بْنِ مَيْسَرَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ الْمُقْرِئُ، حَدَّثَنَا حَيْوَةُ بْنُ شُرَيْحٍ، قَالَ سَمِعْتُ عُقْبَةَ بْنَ مُسْلِمٍ، يَقُولُ حَدَّثَنِي أَبُو عَبْدِ الرَّحْمَنِ الْحُبُلِيُّ، عَنِ الصُّنَابِحِيِّ، عَنْ مُعَاذِ بْنِ جَبَلٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَخَذَ بِيَدِهِ وَقَالَ ‏"‏ يَا مُعَاذُ وَاللَّهِ إِنِّي لأُحِبُّكَ وَاللَّهِ إِنِّي لأُحِبُّكَ ‏"‏ ‏.‏ فَقَالَ ‏"‏ أُوصِيكَ يَا مُعَاذُ لاَ تَدَعَنَّ فِي دُبُرِ كُلِّ صَلاَةٍ تَقُولُ اللَّهُمَّ أَعِنِّي عَلَى ذِكْرِكَ وَشُكْرِكَ وَحُسْنِ عِبَادَتِكَ ‏"‏ ‏.‏ وَأَوْصَى بِذَلِكَ مُعَاذٌ الصُّنَابِحِيَّ وَأَوْصَى بِهِ الصُّنَابِحِيُّ أَبَا عَبْدِ الرَّحْمَنِ ‏.‏\hadithno{1522}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Mu'adh b. Jabal reported that the Messenger of Allah (ﷺ) caught his hand and said:By Allah, I love you, Mu'adh. I give some instruction to you. Never leave to recite this supplication after every (prescribed) prayer: "O Allah, help me in remembering You, in giving You thanks, and worshipping You well." Mu'adh willed this supplication to the narrator al-Sunabihi and al-Sunabihi to 'Abu Abd al-Rahman}}
\hadithdefcmd{abudawud}{1523}{حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ الْمُرَادِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنِ اللَّيْثِ بْنِ سَعْدٍ، أَنَّ حُنَيْنَ بْنَ أَبِي حَكِيمٍ، حَدَّثَهُ عَنْ عُلَىِّ بْنِ رَبَاحٍ اللَّخْمِيِّ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، قَالَ أَمَرَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ أَقْرَأَ بِالْمُعَوِّذَاتِ دُبُرَ كُلِّ صَلاَةٍ ‏.‏\hadithno{1523}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Uqbah ibn Amir: The Messenger of Allah (ﷺ) commanded me to recite Mu'awwidhatan (the last two surahs of the Qur'an) after every prayer}}
\hadithdefcmd{abudawud}{1524}{حَدَّثَنَا أَحْمَدُ بْنُ عَلِيِّ بْنِ سُوَيْدٍ السَّدُوسِيُّ، حَدَّثَنَا أَبُو دَاوُدَ، عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، عَنْ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُعْجِبُهُ أَنْ يَدْعُوَ ثَلاَثًا وَيَسْتَغْفِرَ ثَلاَثًا ‏.‏\hadithno{1524}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Mas'ud: The Messenger of Allah (ﷺ) liked to supplicate three times and to ask pardon (of Allah) three times}}
\hadithdefcmd{abudawud}{1525}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دَاوُدَ، عَنْ عَبْدِ الْعَزِيزِ بْنِ عُمَرَ، عَنْ هِلاَلٍ، عَنْ عُمَرَ بْنِ عَبْدِ الْعَزِيزِ، عَنِ ابْنِ جَعْفَرٍ، عَنْ أَسْمَاءَ بِنْتِ عُمَيْسٍ، قَالَتْ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَلاَ أُعَلِّمُكِ كَلِمَاتٍ تَقُولِينَهُنَّ عِنْدَ الْكَرْبِ أَوْ فِي الْكَرْبِ اللَّهُ اللَّهُ رَبِّي لاَ أُشْرِكُ بِهِ شَيْئًا ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا هِلاَلٌ مَوْلَى عُمَرَ بْنِ عَبْدِ الْعَزِيزِ وَابْنُ جَعْفَرٍ هُوَ عَبْدُ اللَّهِ بْنُ جَعْفَرٍ ‏.‏\hadithno{1525}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Asma' daughter of Umays: The Messenger of Allah (ﷺ) said to me: May I not teach you phrases which you utter in distress? (These are:) "Allah , Allah is my Lord, I do not associate anything as partner with Him." Abu Dawud said: The narrator Hilal is a client of 'Umar b. 'Abd al-Aziz. The name of Ja'far, a narrator, is 'Abd Allah b. Ja'far}}
\hadithdefcmd{abudawud}{1526}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ ثَابِتٍ، وَعَلِيِّ بْنِ زَيْدٍ، وَسَعِيدٍ الْجُرَيْرِيِّ، عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ، أَنَّ أَبَا مُوسَى الأَشْعَرِيَّ، قَالَ كُنْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي سَفَرٍ فَلَمَّا دَنَوْا مِنَ الْمَدِينَةِ كَبَّرَ النَّاسُ وَرَفَعُوا أَصْوَاتَهُمْ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا أَيُّهَا النَّاسُ إِنَّكُمْ لاَ تَدْعُونَ أَصَمَّ وَلاَ غَائِبًا إِنَّ الَّذِي تَدْعُونَهُ بَيْنَكُمْ وَبَيْنَ أَعْنَاقِ رِكَابِكُمْ ‏"‏ ‏.‏ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا أَبَا مُوسَى أَلاَ أَدُلُّكَ عَلَى كَنْزٍ مِنْ كُنُوزِ الْجَنَّةِ ‏"‏ ‏.‏ فَقُلْتُ وَمَا هُوَ قَالَ ‏"‏ لاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ ‏"‏ ‏.‏\hadithno{1526}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Munkar; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated AbuMusa al-Ash'ari: Once we accompanied the Messenger of Allah (ﷺ) on a journey. When we reached near Medina, the people began to say aloud: "Allah is most great," and they raised their voice. The Messenger of Allah (ﷺ) said: O people, you are not supplicating one who is deaf and absent, but you are supplicating One Who is nearer to you than the neck of your riding beast. The Messenger of Allah (ﷺ) then said: AbuMusa, should I not point out to you one of the treasures of Paradise? I asked: What is that? He replied: "There is no might and there is no power except in Allah}}
\hadithdefcmd{abudawud}{1527}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا سُلَيْمَانُ التَّيْمِيُّ، عَنْ أَبِي عُثْمَانَ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، أَنَّهُمْ كَانُوا مَعَ النَّبِيِّ صلى الله عليه وسلم وَهُمْ يَتَصَعَّدُونَ فِي ثَنِيَّةٍ فَجَعَلَ رَجُلٌ كُلَّمَا عَلاَ الثَّنِيَّةَ نَادَى لاَ إِلَهَ إِلاَّ اللَّهُ وَاللَّهُ أَكْبَرُ ‏.‏ فَقَالَ نَبِيُّ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّكُمْ لاَ تُنَادُونَ أَصَمَّ وَلاَ غَائِبًا ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ يَا عَبْدَ اللَّهِ بْنَ قَيْسٍ ‏"‏ ‏.‏ فَذَكَرَ مَعْنَاهُ ‏.‏\hadithno{1527}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6610) Sahih Muslim (2704)}\hadithtrans{Abu Musa Al-Ash'ari said:They (the Companions) accompanied the Prophet (ﷺ) while they were climbing the turning of a hill. A man uttered loudly: "There is no god but Allah, and Allah is most great" when he ascended the hill.	The Prophet of Allah (ﷺ) said: You are not supplicating one who is deaf or absent. He then said: 'Abd Allah b. Qais. The narrator then transmitted the tradition to the same effect}}
\hadithdefcmd{abudawud}{1528}{حَدَّثَنَا أَبُو صَالِحٍ، مَحْبُوبُ بْنُ مُوسَى أَخْبَرَنَا أَبُو إِسْحَاقَ الْفَزَارِيُّ، عَنْ عَاصِمٍ، عَنْ أَبِي عُثْمَانَ، عَنْ أَبِي مُوسَى، بِهَذَا الْحَدِيثِ وَقَالَ فِيهِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ يَا أَيُّهَا النَّاسُ ارْبَعُوا عَلَى أَنْفُسِكُمْ ‏"‏ ‏.‏\hadithno{1528}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6206) Sahih Muslim (2704)}\hadithtrans{The aforesaid tradition has also been transmitted by Abu Musa al-Ash'ari through a different chain of narrators. This version adds:Be lenient to yourselves, O people}}
\hadithdefcmd{abudawud}{1529}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا أَبُو الْحُسَيْنِ، زَيْدُ بْنُ الْحُبَابِ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ شُرَيْحٍ الإِسْكَنْدَرَانِيُّ، حَدَّثَنِي أَبُو هَانِئٍ الْخَوْلاَنِيُّ، أَنَّهُ سَمِعَ أَبَا عَلِيٍّ الْجَنْبِيَّ، أَنَّهُ سَمِعَ أَبَا سَعِيدٍ الْخُدْرِيَّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَالَ رَضِيتُ بِاللَّهِ رَبًّا وَبِالإِسْلاَمِ دِينًا وَبِمُحَمَّدٍ رَسُولاً وَجَبَتْ لَهُ الْجَنَّةُ ‏"‏ ‏.‏\hadithno{1529}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Sa'id al-Khudri reported the Messenger of Allah (ﷺ) as saying:If anyone says "I am pleased with Allah as Lord, with Islam as religion and with Muhammad (ﷺ) as Apostle" Paradise will be his due}}
\hadithdefcmd{abudawud}{1530}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْعَتَكِيُّ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ صَلَّى عَلَىَّ وَاحِدَةً صَلَّى اللَّهُ عَلَيْهِ عَشْرًا ‏"‏ ‏.‏\hadithno{1530}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (408)}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: If anyone invokes blessings on me once, Allah will bless him ten times}}
\hadithdefcmd{abudawud}{1531}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا الْحُسَيْنُ بْنُ عَلِيٍّ الْجُعْفِيُّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ بْنِ جَابِرٍ، عَنْ أَبِي الأَشْعَثِ الصَّنْعَانِيِّ، عَنْ أَوْسِ بْنِ أَوْسٍ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّ مِنْ أَفْضَلِ أَيَّامِكُمْ يَوْمَ الْجُمُعَةِ فَأَكْثِرُوا عَلَىَّ مِنَ الصَّلاَةِ فِيهِ فَإِنَّ صَلاَتَكُمْ مَعْرُوضَةٌ عَلَىَّ ‏"‏ ‏.‏ قَالَ فَقَالُوا يَا رَسُولَ اللَّهِ وَكَيْفَ تُعْرَضُ صَلاَتُنَا عَلَيْكَ وَقَدْ أَرِمْتَ قَالَ يَقُولُونَ بَلِيتَ ‏.‏ قَالَ ‏"‏ إِنَّ اللَّهَ تَبَارَكَ وَتَعَالَى حَرَّمَ عَلَى الأَرْضِ أَجْسَادَ الأَنْبِيَاءِ صَلَّى اللَّهُ عَلَيْهِمْ ‏"‏ ‏.‏\hadithno{1531}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Aws b. Aws reported the Messenger of Allah (ﷺ) as saying:Among the most excellent of your days is Friday; so invoke many blessings on me on that day, for your blessing will be submitted to me. They (the Companions) asked: Messenger of Allah, how can our blessings be submitted to you, when your body has decayed? He (ﷺ) said: Allah has prohibited the earth from consuming the bodies of Prophets}}
\hadithdefcmd{abudawud}{1532}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، وَيَحْيَى بْنُ الْفَضْلِ، وَسُلَيْمَانُ بْنُ عَبْدِ الرَّحْمَنِ، قَالُوا حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا يَعْقُوبُ بْنُ مُجَاهِدٍ أَبُو حَزْرَةَ، عَنْ عُبَادَةَ بْنِ الْوَلِيدِ بْنِ عُبَادَةَ بْنِ الصَّامِتِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَدْعُوا عَلَى أَنْفُسِكُمْ وَلاَ تَدْعُوا عَلَى أَوْلاَدِكُمْ وَلاَ تَدْعُوا عَلَى خَدَمِكُمْ وَلاَ تَدْعُوا عَلَى أَمْوَالِكُمْ لاَ تُوَافِقُوا مِنَ اللَّهِ تَبَارَكَ وَتَعَالَى سَاعَةَ نَيْلٍ فِيهَا عَطَاءٌ فَيَسْتَجِيبَ لَكُمْ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا الْحَدِيثُ مُتَّصِلُ الإِسْنَادِ فَإِنَّ عُبَادَةَ بْنَ الْوَلِيدِ بْنِ عُبَادَةَ لَقِيَ جَابِرًا ‏.‏\hadithno{1532}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Jabir b. 'Abd Allah reported the Messenger of Allah (ﷺ) as saying:Do not invoke curse on yourselves, and do not invoke curse on your children, and do not invoke curse on your servants, and do not invoke curse on your property, lest you happen to do it at a time when Allah is asked for something and grants your request. Abu Dawud said: This Hadith has a continuous chain of narrators, 'Ubadah bin Al-Walid bin 'Ubadah (did) met Jabir}}
\hadithdefcmd{abudawud}{1533}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، حَدَّثَنَا أَبُو عَوَانَةَ، عَنِ الأَسْوَدِ بْنِ قَيْسٍ، عَنْ نُبَيْحٍ الْعَنَزِيِّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ امْرَأَةً، قَالَتْ لِلنَّبِيِّ صلى الله عليه وسلم صَلِّ عَلَىَّ وَعَلَى زَوْجِي ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ صَلَّى اللَّهُ عَلَيْكِ وَعَلَى زَوْجِكِ ‏"‏ ‏.‏\hadithno{1533}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Jabir ibn Abdullah: A woman said to the Prophet (ﷺ): Invoke blessing on me as well as on my husband. The Prophet (ﷺ) said: May Allah send blessing on you and your husband}}
\hadithdefcmd{abudawud}{1534}{حَدَّثَنَا رَجَاءُ بْنُ الْمُرَجَّى، حَدَّثَنَا النَّضْرُ بْنُ شُمَيْلٍ، أَخْبَرَنَا مُوسَى بْنُ ثَرْوَانَ، حَدَّثَنِي طَلْحَةُ بْنُ عُبَيْدِ اللَّهِ بْنِ كَرِيزٍ، حَدَّثَتْنِي أُمُّ الدَّرْدَاءِ، قَالَتْ حَدَّثَنِي سَيِّدِي أَبُو الدَّرْدَاءِ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا دَعَا الرَّجُلُ لأَخِيهِ بِظَهْرِ الْغَيْبِ قَالَتِ الْمَلاَئِكَةُ آمِينَ وَلَكَ بِمِثْلٍ ‏"‏ ‏.‏\hadithno{1534}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2732)}\hadithtrans{Abu Al-Darda' said:I heard the Messenger of Allah (ﷺ) say: When a Muslim supplicates for his absent brother the angels say: Amin, and may you receive the like}}
\hadithdefcmd{abudawud}{1535}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، حَدَّثَنَا ابْنُ وَهْبٍ، حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ زِيَادٍ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ أَسْرَعَ الدُّعَاءِ إِجَابَةً دَعْوَةُ غَائِبٍ لِغَائِبٍ ‏"‏ ‏.‏\hadithno{1535}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: The Prophet (ﷺ) said: The supplication which gets the quickest answer is that made by one distant Muslim for another}}
\hadithdefcmd{abudawud}{1536}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هِشَامٌ الدَّسْتَوَائِيُّ، عَنْ يَحْيَى، عَنْ أَبِي جَعْفَرٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ ثَلاَثُ دَعَوَاتٍ مُسْتَجَابَاتٌ لاَ شَكَّ فِيهِنَّ دَعْوَةُ الْوَالِدِ وَدَعْوَةُ الْمُسَافِرِ وَدَعْوَةُ الْمَظْلُومِ ‏"‏ ‏.‏\hadithno{1536}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: Three supplications are answered, there being no doubt about them; that of a father, that of a traveller and that of one who has been wronged}}
\hadithdefcmd{abudawud}{1537}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ أَبِي بُرْدَةَ بْنِ عَبْدِ اللَّهِ، أَنَّ أَبَاهُ، حَدَّثَهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا خَافَ قَوْمًا قَالَ ‏ "‏ اللَّهُمَّ إِنَّا نَجْعَلُكَ فِي نُحُورِهِمْ وَنَعُوذُ بِكَ مِنْ شُرُورِهِمْ ‏"‏ ‏.‏\hadithno{1537}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuMusa al-Ash'ari: When the Prophet (ﷺ) feared a (group of) people, he would say: "O Allah, we make Thee our shield against them, and take refuge in Thee from their evils}}
\hadithdefcmd{abudawud}{1538}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، وَعَبْدُ الرَّحْمَنِ بْنُ مُقَاتِلٍ، خَالُ الْقَعْنَبِيِّ وَمُحَمَّدُ بْنُ عِيسَى - الْمَعْنَى وَاحِدٌ - قَالُوا حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ أَبِي الْمَوَالِ، حَدَّثَنِي مُحَمَّدُ بْنُ الْمُنْكَدِرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُعَلِّمُنَا الاِسْتِخَارَةَ كَمَا يُعَلِّمُنَا السُّورَةَ مِنَ الْقُرْآنِ يَقُولُ لَنَا ‏"‏ إِذَا هَمَّ أَحَدُكُمْ بِالأَمْرِ فَلْيَرْكَعْ رَكْعَتَيْنِ مِنْ غَيْرِ الْفَرِيضَةِ وَلْيَقُلِ اللَّهُمَّ إِنِّي أَسْتَخِيرُكَ بِعِلْمِكَ وَأَسْتَقْدِرُكَ بِقُدْرَتِكَ وَأَسْأَلُكَ مِنْ فَضْلِكَ الْعَظِيمِ فَإِنَّكَ تَقْدِرُ وَلاَ أَقْدِرُ وَتَعْلَمُ وَلاَ أَعْلَمُ وَأَنْتَ عَلاَّمُ الْغُيُوبِ اللَّهُمَّ إِنْ كُنْتَ تَعْلَمُ أَنَّ هَذَا الأَمْرَ - يُسَمِّيهِ بِعَيْنِهِ الَّذِي يُرِيدُ - خَيْرٌ لِي فِي دِينِي وَمَعَاشِي وَمَعَادِي وَعَاقِبَةِ أَمْرِي فَاقْدُرْهُ لِي وَيَسِّرْهُ لِي وَبَارِكْ لِي فِيهِ اللَّهُمَّ وَإِنْ كُنْتَ تَعْلَمُهُ شَرًّا لِي مِثْلَ الأَوَّلِ فَاصْرِفْنِي عَنْهُ وَاصْرِفْهُ عَنِّي وَاقْدُرْ لِيَ الْخَيْرَ حَيْثُ كَانَ ثُمَّ رَضِّنِي بِهِ ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ فِي عَاجِلِ أَمْرِي وَآجِلِهِ ‏"‏ ‏.‏ قَالَ ابْنُ مَسْلَمَةَ وَابْنُ عِيسَى عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ عَنْ جَابِرٍ ‏.‏\hadithno{1538}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1162)}\hadithtrans{Jabir b. 'Abd Allah said:The Messenger of Allah (ﷺ) used to teach us the supplication for isthikharah (seeking what us beneficial from Allah) as he would teach us a surah (chapter) from the Qur'an. He would tell us: When one of you intends to do a work, he should offer two supererogatory rak'ahs of prayer, and then say (at the end of the prayer): "O Allah, I seek Your choice on the better (of the two matters) based upon Your knowledge, and I seek Your decree based upon Your power, and I ask You for Your great bounties. For Indeed, You are the One Who Decrees, and I do not decree, and You know, and I do not know, and You are the Knower of the Unseen. O Allah, if you know this, and You are the Knower of the Unseen. O Allah, if you know this - here he should name exactly what he wishes - is better for me with regard to my religion, and my life, and my afterlife, and the end result of my affairs, then decree it to me, and make it easy for me, and bless me on it. O Allah, and if You know this to be evil for me - and he says just as he said the first time - then avert it for me, and avert me from it. And decree for me good wherever it might be, the make me content with it." A version goes: "If the work is good immediately or subsequently." Ibn Maslamah and Ibn 'Isa reported from Muhammad b. al-Munkadir on the authority of Jabir}}
\hadithdefcmd{abudawud}{1539}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَتَعَوَّذُ مِنْ خَمْسٍ مِنَ الْجُبْنِ وَالْبُخْلِ وَسُوءِ الْعُمْرِ وَفِتْنَةِ الصَّدْرِ وَعَذَابِ الْقَبْرِ ‏.‏\hadithno{1539}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Umar ibn al-Khattab: The Prophet (ﷺ) used to seek refuge in Allah from five things; cowardliness, niggardliness, the evils of old age, evil thoughts, and punishment in the grave}}
\hadithdefcmd{abudawud}{1540}{حَدَّثَنَا مُسَدَّدٌ، أَخْبَرَنَا الْمُعْتَمِرُ، قَالَ سَمِعْتُ أَبِي قَالَ، سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْعَجْزِ وَالْكَسَلِ وَالْجُبْنِ وَالْبُخْلِ وَالْهَرَمِ وَأَعُوذُ بِكَ مِنْ عَذَابِ الْقَبْرِ وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الْمَحْيَا وَالْمَمَاتِ ‏"‏ ‏.‏\hadithno{1540}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2823) Sahih Muslim (2706)}\hadithtrans{Anas b. Malik said:The Messenger of Allah (ﷺ) used to say: "O Allah, I seek refuge in You from weakness, and laziness, and cowardice, and old age, and I seek refuge in You from the punishment of the grave, and I seek refuge in You from the trails of the life and death}}
\hadithdefcmd{abudawud}{1541}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا يَعْقُوبُ بْنُ عَبْدِ الرَّحْمَنِ، - قَالَ سَعِيدٌ الزُّهْرِيُّ - عَنْ عَمْرِو بْنِ أَبِي عَمْرٍو، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كُنْتُ أَخْدُمُ النَّبِيَّ صلى الله عليه وسلم فَكُنْتُ أَسْمَعُهُ كَثِيرًا يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْهَمِّ وَالْحَزَنِ وَضَلْعِ الدَّيْنِ وَغَلَبَةِ الرِّجَالِ ‏"‏ ‏.‏ وَذَكَرَ بَعْضَ مَا ذَكَرَهُ التَّيْمِيُّ ‏.‏\hadithno{1541}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6369)}\hadithtrans{Anas b. Malik said:I used to serve the Prophet (ﷺ) and often hear him say: "O Allah, I seek refuge in You from grief and anxiety, from the hardships of debt, and from being overpowered by men}}
\hadithdefcmd{abudawud}{1542}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ أَبِي الزُّبَيْرِ الْمَكِّيِّ، عَنْ طَاوُسٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُعَلِّمُهُمْ هَذَا الدُّعَاءَ كَمَا يُعَلِّمُهُمُ السُّورَةَ مِنَ الْقُرْآنِ يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ عَذَابِ جَهَنَّمَ وَأَعُوذُ بِكَ مِنْ عَذَابِ الْقَبْرِ وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الْمَسِيحِ الدَّجَّالِ وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الْمَحْيَا وَالْمَمَاتِ ‏"‏ ‏.‏\hadithno{1542}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (590)}\hadithtrans{Abd Allah b. 'Abbas said:The Messenger of Allah (ﷺ) used to teach us this supplication as he taught us the surah from the Qur'an. He would say: O Allah! I seek refuge in You from the punishment of Hell and I seek refuge in You from the punishment of the grave, and I seek refuge from You from the trails of Al-Masihid-Dajjal, and I seek refuge in You from the trials of life and death}}
\hadithdefcmd{abudawud}{1543}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى الرَّازِيُّ، أَخْبَرَنَا عِيسَى، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، رضى الله عنها أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَدْعُو بِهَؤُلاَءِ الْكَلِمَاتِ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ فِتْنَةِ النَّارِ وَعَذَابِ النَّارِ وَمِنْ شَرِّ الْغِنَى وَالْفَقْرِ ‏"‏ ‏.‏\hadithno{1543}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6368) Sahih Muslim (589 After  2705)}\hadithtrans{Aishah narrated that the Prophet (ﷺ) would supplicate with the following words:"O Allah! I seek refuge in You from the trials of the Fire, and the punishment of the Fire, and from the evils of richness and poverty}}
\hadithdefcmd{abudawud}{1544}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا إِسْحَاقُ بْنُ عَبْدِ اللَّهِ، عَنْ سَعِيدِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْفَقْرِ وَالْقِلَّةِ وَالذِّلَّةِ وَأَعُوذُ بِكَ مِنْ أَنْ أَظْلِمَ أَوْ أُظْلَمَ ‏"‏ ‏.‏\hadithno{1544}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) used to say: "O Allah, I seek refuge in Thee from poverty", lack and abasement, and I seek refuge in Thee lest I cause or suffer wrong}}
\hadithdefcmd{abudawud}{1545}{حَدَّثَنَا ابْنُ عَوْفٍ، حَدَّثَنَا عَبْدُ الْغَفَّارِ بْنُ دَاوُدَ، حَدَّثَنَا يَعْقُوبُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ مِنْ دُعَاءِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ زَوَالِ نِعْمَتِكَ وَتَحْوِيلِ عَافِيَتِكَ وَفُجَاءَةِ نِقْمَتِكَ وَجَمِيعِ سَخَطِكَ ‏"‏ ‏.‏\hadithno{1545}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2739)}\hadithtrans{Abd Allah b. 'Umar said that one of the supplications of the Messenger of Allah (ﷺ) was:"O Allah, I seek refuge in You that Your blessings are lifted, and Your protection (of me) is changed, and in the suddenness of Your punishment, and from all Your anger}}
\hadithdefcmd{abudawud}{1546}{حَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ، حَدَّثَنَا بَقِيَّةُ، حَدَّثَنَا ضُبَارَةُ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي السَّلِيكِ، عَنْ دُوَيْدِ بْنِ نَافِعٍ، حَدَّثَنَا أَبُو صَالِحٍ السَّمَّانُ، قَالَ قَالَ أَبُو هُرَيْرَةَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَدْعُو يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الشِّقَاقِ وَالنِّفَاقِ وَسُوءِ الأَخْلاَقِ ‏"‏ ‏.‏\hadithno{1546}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuHurayrah: The Messenger of Allah (ﷺ) used to supplicate by saying: "O Allah, I seek refuge in Thee from divisiveness, hypocrisy, and evil character}}
\hadithdefcmd{abudawud}{1547}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، عَنِ ابْنِ إِدْرِيسَ، عَنِ ابْنِ عَجْلاَنَ، عَنِ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْجُوعِ فَإِنَّهُ بِئْسَ الضَّجِيعُ وَأَعُوذُ بِكَ مِنَ الْخِيَانَةِ فَإِنَّهَا بِئْسَتِ الْبِطَانَةُ ‏"‏ ‏.‏\hadithno{1547}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuHurayrah: The Messenger of Allah (ﷺ) used to say: "O Allah, I seek refuge in Thee from hunger, for it is an evil bed-fellow; and I seek refuge in Thee from treachery, for it is an evil hidden trait}}
\hadithdefcmd{abudawud}{1548}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَخِيهِ، عَبَّادِ بْنِ أَبِي سَعِيدٍ أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الأَرْبَعِ مِنْ عِلْمٍ لاَ يَنْفَعُ وَمِنْ قَلْبٍ لاَ يَخْشَعُ وَمِنْ نَفْسٍ لاَ تَشْبَعُ وَمِنْ دُعَاءٍ لاَ يُسْمَعُ ‏"‏ ‏.‏\hadithno{1548}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: The Messenger of Allah (ﷺ) used to say: "O Allah, I seek refuge in Thee from four things: Knowledge which does not profit, a heart which is not submissive, a soul which has an insatiable appetite, and a supplication which is not heard}}
\hadithdefcmd{abudawud}{1549}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُتَوَكِّلِ، حَدَّثَنَا الْمُعْتَمِرُ، قَالَ قَالَ أَبُو الْمُعْتَمِرِ أُرَى أَنَّ أَنَسَ بْنَ مَالِكٍ، حَدَّثَنَا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ صَلاَةٍ لاَ تَنْفَعُ ‏"‏ ‏.‏ وَذَكَرَ دُعَاءً آخَرَ ‏.‏\hadithno{1549}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Anas bin Malik narrated that the Prophet (ﷺ) would say:"O Allah, I seek refuge in You from a prayer that is of no benefit}}
\hadithdefcmd{abudawud}{1550}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ هِلاَلِ بْنِ يِسَافٍ، عَنْ فَرْوَةَ بْنِ نَوْفَلٍ الأَشْجَعِيِّ، قَالَ سَأَلْتُ عَائِشَةَ أُمَّ الْمُؤْمِنِينَ عَمَّا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدْعُو بِهِ قَالَتْ كَانَ يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ شَرِّ مَا عَمِلْتُ وَمِنْ شَرِّ مَا لَمْ أَعْمَلْ ‏"‏ ‏.‏\hadithno{1550}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2716)}\hadithtrans{Farwah b. Nawfal Al-Ashja'i asked 'Aishah the Mother of the Believers, about the supplication of the Messenger of Allah (ﷺ). She replied:"He would say: 'O Allah, I seek refuge in You from the evil of what I have done, and from the evil of what I have not done}}
\hadithdefcmd{abudawud}{1551}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ حَنْبَلٍ، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، ح وَحَدَّثَنَا أَحْمَدُ، حَدَّثَنَا وَكِيعٌ، - الْمَعْنَى - عَنْ سَعْدِ بْنِ أَوْسٍ، عَنْ بِلاَلٍ الْعَبْسِيِّ، عَنْ شُتَيْرِ بْنِ شَكَلٍ، عَنْ أَبِيهِ، فِي حَدِيثِ أَبِي أَحْمَدَ شَكَلِ بْنِ حُمَيْدٍ - قَالَ - قُلْتُ يَا رَسُولَ اللَّهِ عَلِّمْنِي دُعَاءً قَالَ ‏ "‏ قُلِ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ شَرِّ سَمْعِي وَمِنْ شَرِّ بَصَرِي وَمِنْ شَرِّ لِسَانِي وَمِنْ شَرِّ قَلْبِي وَمِنْ شَرِّ مَنِيِّي ‏"‏ ‏.‏\hadithno{1551}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Shakl ibn Humayd: I said: Messenger of Allah, teach me a supplication. He said: Say: "O Allah, I seek refuge in Thee from the evil of what I hear, from the evil of what I see, from the evil of what I speak, from the evil of what I think, and from the evil of my semen" (i.e. sexual passion)}}
\hadithdefcmd{abudawud}{1552}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، حَدَّثَنَا مَكِّيُّ بْنُ إِبْرَاهِيمَ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ سَعِيدٍ، عَنْ صَيْفِيٍّ، مَوْلَى أَفْلَحَ مَوْلَى أَبِي أَيُّوبَ عَنْ أَبِي الْيَسَرِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَدْعُو ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْهَدْمِ وَأَعُوذُ بِكَ مِنَ التَّرَدِّي وَأَعُوذُ بِكَ مِنَ الْغَرَقِ وَالْحَرَقِ وَالْهَرَمِ وَأَعُوذُ بِكَ أَنْ يَتَخَبَّطَنِي الشَّيْطَانُ عِنْدَ الْمَوْتِ وَأَعُوذُ بِكَ أَنْ أَمُوتَ فِي سَبِيلِكَ مُدْبِرًا وَأَعُوذُ بِكَ أَنْ أَمُوتَ لَدِيغًا ‏"‏ ‏.‏\hadithno{1552}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated AbulYusr: The Messenger of Allah (ﷺ) used to supplicate: "O Allah, I seek refuge in Thee from my house falling on me, I seek refuge in Thee from falling into an abyss, I seek refuge in Thee from drowning burning and decrepitude. I seek refuge in Thee from the devil harming me at the time of my death, I seek refuge in Thee from dying in Thy path while retreating, and I seek refuge in Thee from dying of the sting of a poisonous creature}}
\hadithdefcmd{abudawud}{1553}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى الرَّازِيُّ، أَخْبَرَنَا عِيسَى، عَنْ عَبْدِ اللَّهِ بْنِ سَعِيدٍ، حَدَّثَنِي مَوْلًى، لأَبِي أَيُّوبَ عَنْ أَبِي الْيَسَرِ، زَادَ فِيهِ ‏ "‏ وَالْغَمِّ ‏"‏ ‏.‏\hadithno{1553}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{The aforesaid tradition has also been transmitted by Abu al-Yusr through a different chain of narrators. This version adds:"and from sorrow}}
\hadithdefcmd{abudawud}{1554}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا قَتَادَةُ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْبَرَصِ وَالْجُنُونِ وَالْجُذَامِ وَمِنْ سَيِّئِ الأَسْقَامِ ‏"‏ ‏.‏\hadithno{1554}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas ibn Malik: The Prophet (ﷺ) used to say: "O Allah, I seek refuge in Thee from leprosy, madness, elephantiasis, and evil diseases}}
\hadithdefcmd{abudawud}{1555}{حَدَّثَنَا أَحْمَدُ بْنُ عُبَيْدِ اللَّهِ الْغُدَانِيُّ، أَخْبَرَنَا غَسَّانُ بْنُ عَوْفٍ، أَخْبَرَنَا الْجُرَيْرِيُّ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ دَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم ذَاتَ يَوْمٍ الْمَسْجِدَ فَإِذَا هُوَ بِرَجُلٍ مِنَ الأَنْصَارِ يُقَالُ لَهُ أَبُو أُمَامَةَ فَقَالَ ‏"‏ يَا أَبَا أُمَامَةَ مَا لِي أَرَاكَ جَالِسًا فِي الْمَسْجِدِ فِي غَيْرِ وَقْتِ الصَّلاَةِ ‏"‏ ‏.‏ قَالَ هُمُومٌ لَزِمَتْنِي وَدُيُونٌ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ أَفَلاَ أُعَلِّمُكَ كَلاَمًا إِذَا أَنْتَ قُلْتَهُ أَذْهَبَ اللَّهُ عَزَّ وَجَلَّ هَمَّكَ وَقَضَى عَنْكَ دَيْنَكَ ‏"‏ ‏.‏ قَالَ قُلْتُ بَلَى يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ قُلْ إِذَا أَصْبَحْتَ وَإِذَا أَمْسَيْتَ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْهَمِّ وَالْحَزَنِ وَأَعُوذُ بِكَ مِنَ الْعَجْزِ وَالْكَسَلِ وَأَعُوذُ بِكَ مِنَ الْجُبْنِ وَالْبُخْلِ وَأَعُوذُ بِكَ مِنْ غَلَبَةِ الدَّيْنِ وَقَهْرِ الرِّجَالِ ‏"‏ ‏.‏ قَالَ فَفَعَلْتُ ذَلِكَ فَأَذْهَبَ اللَّهُ عَزَّ وَجَلَّ هَمِّي وَقَضَى عَنِّي دَيْنِي ‏.‏\hadithno{1555}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuSa'id al-Khudri: One day the Messenger of Allah (ﷺ) entered the mosque. He saw there a man from the Ansar called AbuUmamah. He said: What is the matter that I am seeing you sitting in the mosque when there is no time of prayer? He said: I am entangled in cares and debts, Messenger of Allah. He replied: Shall I not teach you words by which, when you say them, Allah will remove your care, and settle your debt? He said: Why not, Messenger of Allah? He said: Say in the morning and evening: "O Allah, I seek refuge in Thee from care and grief, I seek refuge in Thee from incapacity and slackness, I seek refuge in Thee from cowardice and niggardliness, and I seek in Thee from being overcome by debt and being put in subjection by men." He said: When I did that Allah removed my care and settled my debt}}
